@@ -9,7 +9,7 @@
 
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -23,20 +23,25 @@
 */
 
 #include <EOModeler/EOMInspector.h>
+
+#ifdef NeXT_GUI_LIBRARY
 #include <AppKit/AppKit.h>
+#else
+#include <AppKit/AppKit.h>
+#endif
 
 @class EOModel;
 @class EOEntity;
 @interface RelationshipInspector : EOMInspector
 {
-  IBOutlet NSTextField		*name_textField;
-  IBOutlet NSPopUpButton	*model_popup;
-  IBOutlet NSMatrix		*joinCardinality_matrix;
-  IBOutlet NSPopUpButton	*joinSemantic_popup;
-  IBOutlet NSTableView		*destEntity_tableView;
-  IBOutlet NSTableView		*srcAttrib_tableView;
-  IBOutlet NSTableView		*destAttrib_tableView;
-  IBOutlet NSButton		*connect_button;
+  IBOutlet NSTextField          *name_textField;
+  IBOutlet NSPopUpButton        *model_popup;
+  IBOutlet NSMatrix             *joinCardinality_matrix;
+  IBOutlet NSPopUpButton        *joinSemantic_popup;
+  IBOutlet NSTableView          *destEntity_tableView;
+  IBOutlet NSTableView          *srcAttrib_tableView;
+  IBOutlet NSTableView          *destAttrib_tableView;
+  IBOutlet NSButton             *connect_button;
 }
 
 - (IBAction) connectionChanged:(id)sender;
