@@ -9,7 +9,7 @@
 
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -32,7 +32,11 @@
 #include <EOModeler/EOModelerApp.h>
 #include <EOModeler/EOModelerDocument.h>
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSArray.h>
+#endif
 
 @implementation RelationshipInspector
 
@@ -46,7 +50,7 @@
   int row = [destEntity_tableView selectedRow];
   NSArray *entities = [[[EOMApp activeDocument] model] entities];
   
-  if (row == -1 || row == NSNotFound || row > [entities count])
+  if (row == -1 || row == NSNotFound || row >= [entities count])
     return nil;
   
   return [[[[EOMApp activeDocument] model] entities] objectAtIndex:row];
@@ -57,11 +61,10 @@
   int row = [destAttrib_tableView selectedRow];
   NSArray *attribs = [[self selectedEntity] attributes];
   
-  if (row == -1 || row == NSNotFound || row > [attribs count])
+  if (row == -1 || row == NSNotFound || row >= [attribs count])
     return nil;
   
-  return [[[self selectedEntity] attributes]
-	  	objectAtIndex:[destAttrib_tableView selectedRow]];
+  return [attribs objectAtIndex:[destAttrib_tableView selectedRow]];
 }
 
 - (EOAttribute *)selectedSourceAttribute
@@ -69,7 +72,7 @@
   int row = [srcAttrib_tableView selectedRow];
   NSArray *attribs = [[[self selectedObject] entity] attributes];
   
-  if (row == -1 || row == NSNotFound || row > [attribs count])
+  if (row == -1 || row == NSNotFound || row >= [attribs count])
     return nil;
   
   return [attribs objectAtIndex:[srcAttrib_tableView selectedRow]];
@@ -129,24 +132,24 @@
     {
       BOOL flag;
       id join = [joins objectAtIndex:i];
-	  
+          
       /* if both arguments are non-nil, both must be equal,
        * if one argument is nil the non-nil argument must be equal */
       flag = ((srcAttrib 
-	       && destAttrib
-	       && [srcAttrib isEqual:[join sourceAttribute]]
-	       && [destAttrib isEqual:[join destinationAttribute]])
-	      || (srcAttrib
-	          && (destAttrib ==  nil)
-	          && [srcAttrib isEqual:[join sourceAttribute]])
-	      || (destAttrib
-	          && (srcAttrib == nil)
-		  && [destAttrib isEqual:[join destinationAttribute]]));
-			  
+               && destAttrib
+               && [srcAttrib isEqual:[join sourceAttribute]]
+               && [destAttrib isEqual:[join destinationAttribute]])
+              || (srcAttrib
+                  && (destAttrib ==  nil)
+                  && [srcAttrib isEqual:[join sourceAttribute]])
+              || (destAttrib
+                  && (srcAttrib == nil)
+                  && [destAttrib isEqual:[join destinationAttribute]]));
+                          
       if (flag)  
-	{
-	  return join;
-	}
+        {
+          return join;
+        }
     }
   return nil;
 }
@@ -154,7 +157,7 @@
 - (EOJoin *) selectedJoin
 {
   EOJoin *join = [self joinWithSource:[self selectedSourceAttribute]
-	  	  	  destination:[self selectedDestinationAttribute]];
+                              destination:[self selectedDestinationAttribute]];
   return join;
 }
 
@@ -224,13 +227,13 @@
     {
       if ([self numberOfRowsInTableView:srcAttrib_tableView])
         {
-	  [srcAttrib_tableView selectRow:0 byExtendingSelection:NO];
-	}
+          [srcAttrib_tableView selectRow:0 byExtendingSelection:NO];
+        }
 
       if ([self numberOfRowsInTableView:destAttrib_tableView])
         {
-	  [destAttrib_tableView selectRow:0 byExtendingSelection:NO];
-	}
+          [destAttrib_tableView selectRow:0 byExtendingSelection:NO];
+        }
     }
 
   [self updateConnectButton]; 
@@ -252,7 +255,7 @@
     {
       int selectedRow = [destEntity_tableView selectedRow];
       if (selectedRow == -1 || selectedRow == NSNotFound)
-	return 0;
+        return 0;
       return [[(EOEntity *)[[activeModel entities] objectAtIndex:[destEntity_tableView selectedRow]] attributes] count]; 
 
     }
@@ -278,7 +281,7 @@ row:(int)rowIndex
       if (selectedRow == NSNotFound)
         [destEntity_tableView selectRow:0 byExtendingSelection:NO];
       return [(EOAttribute *)[[(EOEntity *)[[activeModel entities] objectAtIndex:[destEntity_tableView selectedRow]]
-				   attributes] objectAtIndex:rowIndex] name]; 
+                                   attributes] objectAtIndex:rowIndex] name]; 
     } 
 
   return nil;
