@@ -11,7 +11,7 @@
 
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -26,13 +26,17 @@
 
 #include <EOModeler/EOModelerEditor.h>
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSOutlineView.h>
 #include <AppKit/NSWindow.h>
 #include <AppKit/NSSplitView.h>
+#endif
 
 @interface MainModelEditor : EOModelerCompoundEditor
 {
-  NSView	*_editorView;
+  NSView    *_editorView;
   NSWindow      *_window;
   NSOutlineView *_iconPath;
   NSSplitView   *_vSplit;
