@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -44,10 +44,21 @@
 
 #include <EOControl/EOObserver.h>
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSOpenPanel.h>
+#endif
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSObject.h>
 #include <Foundation/NSFileManager.h>
+#endif
+
+#include <GNUstepBase/GNUstep.h>
+
 @interface DebugObserver : NSObject <EOObserving> 
 {
 
@@ -60,23 +71,19 @@
 }
 @end
 @interface NSMenu (im_lazy)
--(id <NSMenuItem>) addItemWithTitle: (NSString *)s;
--(id <NSMenuItem>) addItemWithTitle: (NSString *)s  action: (SEL)sel;
-@end
-
-@interface EOModel (foo)
--(void)setCreatesMutableObjects:(BOOL)flag;
+- (NSMenuItem *)addItemWithTitle: (NSString *)s;
+- (NSMenuItem *)addItemWithTitle: (NSString *)s  action: (SEL)sel;
 @end
 
 @implementation NSMenu (im_lazy)
--(id <NSMenuItem>) addItemWithTitle: (NSString *)s
+- (NSMenuItem *)addItemWithTitle: (NSString *)s
 {
-        return [self addItemWithTitle: s  action: NULL  keyEquivalent: nil];
+        return [self addItemWithTitle: s  action: NULL keyEquivalent: @""];
 }
 
--(id <NSMenuItem>) addItemWithTitle: (NSString *)s  action: (SEL)sel
+- (NSMenuItem *)addItemWithTitle: (NSString *)s  action: (SEL)sel
 {
-        return [self addItemWithTitle: s  action: sel  keyEquivalent: nil];
+        return [self addItemWithTitle: s  action: sel  keyEquivalent: @""];
 }
 @end
 
@@ -93,14 +100,13 @@
   int i,c;
   NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
   NSArray *bundlesToLoad = RETAIN([defaults arrayForKey: @"BundlesToLoad"]);
-  NSMenu *mainMenu,*subMenu;
   NSFileManager *fm = [NSFileManager defaultManager];
  
 //  [EOObserverCenter addOmniscientObserver:[DebugObserver new]];
   [[NSNotificationCenter defaultCenter] addObserver:self
-  	selector:@selector(bundleDidLoad:)
-	name:NSBundleDidLoadNotification
-	object:nil];
+        selector:@selector(bundleDidLoad:)
+        name:NSBundleDidLoadNotification
+        object:nil];
   for (i=0, c = [bundlesToLoad count]; i < c; i++)
     {
       BOOL isDir;
@@ -118,134 +124,14 @@
   
   /* useful method for setting breakpoints after an adaptor is loaded */
    
-  mainMenu = [[NSMenu alloc] init];
-  [mainMenu setAutoenablesItems:YES];
-  subMenu = [[NSMenu alloc] init];
-  [subMenu setAutoenablesItems:YES];
-
-  [subMenu addItemWithTitle: _(@"Info...")
-                     action: @selector(orderFrontStandardInfoPanel:)];
-
-  [subMenu addItemWithTitle: _(@"Preferences...")
-                     action: @selector(openPrefs:)];
-
-  [mainMenu setSubmenu: subMenu forItem: [mainMenu addItemWithTitle: _(@"Info")]];
-  [subMenu release];
-
-  subMenu = [[NSMenu alloc] init];
-   
- 
-  [subMenu addItemWithTitle: _(@"New...")
-                     action: @selector(new:)
-              keyEquivalent: @"n"];
-  [subMenu addItemWithTitle: _(@"New from databse...")
-                     action: @selector(newFromDatabase:)
-              keyEquivalent: @""]; 
-
-  [subMenu addItemWithTitle: _(@"Open")
-                     action: @selector(open:)
-              keyEquivalent: @"o"];
-	      
-  [subMenu addItemWithTitle: _(@"Save")
-                     action: @selector(save:)
-              keyEquivalent: @""];
-	      
-  [subMenu addItemWithTitle: _(@"Save As")
-                     action: @selector(saveAs:)
-              keyEquivalent: @""];
-	      
-  [subMenu addItemWithTitle: _(@"Revert")
-                     action: @selector(revert:) 
-              keyEquivalent: @""];
-	      
-  [subMenu addItemWithTitle: _(@"Set Adaptor Info")
-                     action: @selector(setAdaptor:)
-              keyEquivalent: @""];
-	      
-  [subMenu addItemWithTitle: _(@"Switch Adaptor")
-                     action: @selector(switchAdaptor:)
-              keyEquivalent: @""];
-	      
   [ConsistencyChecker class];
-  [[subMenu addItemWithTitle: _(@"Check consistency")
-                     action: @selector(checkConsistency:)
-              keyEquivalent: @""] setRepresentedObject:[ConsistencyResults sharedConsistencyPanel]];
-  
-  [mainMenu setSubmenu: subMenu forItem: [mainMenu addItemWithTitle:_(@"Model")]];
-  [subMenu release];
 
-  subMenu = [[NSMenu alloc] init];
-  
-  subMenu = [[NSMenu alloc] init];
-  [subMenu setAutoenablesItems:YES];
-
-  [subMenu addItemWithTitle: _(@"Copy")
-                     action: @selector(copy:)
-	      keyEquivalent:@"c"];
-  [subMenu addItemWithTitle: _(@"Cut")
-                     action: @selector(cut:)
-	      keyEquivalent:@"x"];
-  [subMenu addItemWithTitle: _(@"Paste")
-                     action: @selector(paste:)
-	      keyEquivalent:@"v"];
-  [mainMenu setSubmenu: subMenu forItem: [mainMenu addItemWithTitle: _(@"Edit")]];
-  [subMenu release];
-
-  
-  subMenu = [[NSMenu alloc] init];
-  [subMenu addItemWithTitle:_(@"Inspector")
-	  	action: @selector(showInspector:)
-		keyEquivalent: @"i"];
-  
-  [subMenu addItemWithTitle: _(@"Generate SQL")
-                     action: @selector(generateSQL:)
-              keyEquivalent: @""]; 
-
-  [subMenu addItemWithTitle: _(@"Table Editor")
-	  	     action: @selector(showEditor:)
-		     keyEquivalent:@""];
-
-  [subMenu addItemWithTitle: _(@"Diagram Editor")
-	  	     action: @selector(showEditor:)
-		     keyEquivalent:@""];
-  [mainMenu setSubmenu:subMenu forItem:[mainMenu addItemWithTitle:_(@"Tools")]];
-  [subMenu release];
-
-  subMenu = [[NSMenu alloc] init];
-  [subMenu setAutoenablesItems:YES];
-  [subMenu addItemWithTitle: _(@"Add entity")
-                     action: @selector(addEntity:)
-              keyEquivalent: @"e"];
-  
-  [subMenu addItemWithTitle: _(@"Add attribute")
-                     action: @selector(addAttribute:)
-              keyEquivalent: @"a"];
-  
-  [subMenu addItemWithTitle: _(@"Add relationship")
-                     action: @selector(addRelationship:)
-              keyEquivalent: @"r"];
-  [subMenu addItemWithTitle: _(@"delete")
-                     action: @selector(delete:)
-              keyEquivalent: @""];
-
-  [mainMenu setSubmenu:subMenu forItem:[mainMenu addItemWithTitle:_(@"Property")]];
-  [subMenu release];
-
-  [mainMenu addItemWithTitle: _(@"Hide")
-                      action: @selector(hide:)
-               keyEquivalent: @"h"];
-
-  [mainMenu addItemWithTitle: _(@"Quit...")
-                      action: @selector(terminate:)
-	       keyEquivalent: @"q"];
-	       
-  [NSApp setMainMenu: mainMenu];
   /* make this a default? */
   [EOModelerDocument setDefaultEditorClass: NSClassFromString(@"MainModelEditor")];
 }
 - (void) showEditor:(id)sender
 {
-  EOModelerCompoundEditor *ed = [EOMApp currentEditor];
+  EOModelerCompoundEditor *ed = (id)[EOMApp currentEditor];
   
   if ([[sender title] isEqual:_(@"Diagram Editor")])
     {
@@ -272,7 +158,7 @@
 - (void)new:(id)sender
 {
   EOModel           *newModel = [[EOModel alloc] init];
-  NSString		*modelName;
+  NSString *modelName;
   NSArray *docs = [EOMApp documents];
   unsigned docNumber, c, i;
 
@@ -332,18 +218,18 @@
       connDict = [adaptor runLoginPanel];
 
       if (connDict)
-	{
-	  [adaptor setConnectionDictionary:[adaptor runLoginPanel]];
-	  ctxt = [adaptor createAdaptorContext];
-	  channel = [ctxt createAdaptorChannel];
-	  [channel openChannel];
-	  newModel = [channel describeModelWithTableNames:[channel describeTableNames]];
-	  [newModel setConnectionDictionary:[adaptor connectionDictionary]];
-	  [newModel setName: [[adaptor connectionDictionary] objectForKey:@"databaseName"]];
-	  [channel closeChannel];
-	  [self _newDocumentWithModel:newModel];
-	  RELEASE(newModel);
-	}
+        {
+          [adaptor setConnectionDictionary:connDict];
+          ctxt = [adaptor createAdaptorContext];
+          channel = [ctxt createAdaptorChannel];
+          [channel openChannel];
+          newModel = [channel describeModelWithTableNames:[channel describeTableNames]];
+          [newModel setConnectionDictionary:[adaptor connectionDictionary]];
+          [newModel setName: [[adaptor connectionDictionary] objectForKey:@"databaseName"]];
+          [channel closeChannel];
+          [self _newDocumentWithModel:newModel];
+          RELEASE(newModel);
+        }
     }
 }
 
@@ -386,23 +272,23 @@
   BOOL flag;
 #if 0
   NSLog(@"%@ %@ %i %i %i %i %i", NSStringFromSelector(_cmd), filename,
-	[fm isReadableFileAtPath:filename] == YES,
-	[pathExt isEqual:@"eomodel"],
-	[pathExt isEqual:@"eomodeld"],
-	[fm fileExistsAtPath:filename isDirectory:&flag],
-	flag);
+        [fm isReadableFileAtPath:filename] == YES,
+        [pathExt isEqual:@"eomodel"],
+        [pathExt isEqual:@"eomodeld"],
+        [fm fileExistsAtPath:filename isDirectory:&flag],
+        flag);
 #endif
   if (([fm isReadableFileAtPath:filename] == YES
        && [pathExt isEqual:@"eomodel"])
       || ([pathExt isEqual:@"eomodeld"]
-	  && [fm fileExistsAtPath:filename isDirectory:&flag] && flag))
+          && [fm fileExistsAtPath:filename isDirectory:&flag] && flag))
     {
       EOModel *model;
 
       NS_DURING
-	model = [[EOModel alloc] initWithContentsOfFile:filename];
+        model = [[EOModel alloc] initWithContentsOfFile:filename];
       NS_HANDLER
-	return NO;
+        return NO;
       NS_ENDHANDLER
 
       [self _newDocumentWithModel:model];
@@ -424,25 +310,25 @@
       
       for (i = 0, c = [modelPaths count]; i < c; i++)
         {
-	  NSString *modelPath = [modelPaths objectAtIndex:i];
+          NSString *modelPath = [modelPaths objectAtIndex:i];
           NSString *pathExt = [[modelPath pathExtension] lowercaseString];
 
-	  if ([fm isReadableFileAtPath:modelPath] == YES
-	      && ([pathExt isEqual:@"eomodeld"]
-		  || [pathExt isEqual:@"eomodel"]))
-	    {
-	      EOModel *model;
-	      
-	      NS_DURING
-		model = [[EOModel alloc] initWithContentsOfFile:modelPath];
-	      NS_HANDLER
-		return;
-	      NS_ENDHANDLER
+          if ([fm isReadableFileAtPath:modelPath] == YES
+              && ([pathExt isEqual:@"eomodeld"]
+                  || [pathExt isEqual:@"eomodel"]))
+            {
+              EOModel *model;
+              
+              NS_DURING
+                model = [[EOModel alloc] initWithContentsOfFile:modelPath];
+              NS_HANDLER
+                return;
+              NS_ENDHANDLER
 
-	      [self _newDocumentWithModel:model];
-	      RELEASE(model);
-	    }
-	}
+              [self _newDocumentWithModel:model];
+              RELEASE(model);
+            }
+        }
     }
 }
 
