@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -28,6 +28,9 @@
 #include "ModelerEntityEditor.h"
 #include "KVDataSource.h"
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSImage.h>
 #include <AppKit/NSTableView.h>
 #include <AppKit/NSTableColumn.h>
@@ -35,16 +38,28 @@
 #include <AppKit/NSPopUpButtonCell.h>
 #include <AppKit/NSScrollView.h>
 #include <AppKit/NSSplitView.h>
+#endif
 
+#include <EOAccess/EOAttribute.h>
 #include <EOAccess/EOEntity.h>
+#include <EOAccess/EORelationship.h>
+
+#include <EOControl/EOEditingContext.h>
 
 #include <EOModeler/EOModelerDocument.h>
 #include <EOModeler/EOModelerApp.h>
 
 #include <EOInterface/EODisplayGroup.h>
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSRunLoop.h>
+#endif
   
+#include <GNUstepBase/GNUstep.h>
+#include <GNUstepBase/GSVersionMacros.h>
+
 @interface NSArray (EOMAdditions)
 - (id) firstSelectionOfClass:(Class) aClass;
 @end
@@ -64,7 +79,16 @@
   /* setup the attributes table view */
   scrollView = [[NSScrollView alloc] initWithFrame:NSMakeRect(0,0,100,100)];
   _attributes_tableView = [[NSTableView alloc] initWithFrame:NSMakeRect(0,0,100,100)];
+#if OS_API_VERSION(GS_API_NONE, MAC_OS_X_VERSION_10_4)
   [_attributes_tableView setAutoresizesAllColumnsToFit:NO];
+#else
+  [_attributes_tableView setColumnAutoresizingStyle:NSTableViewLastColumnOnlyAutoresizingStyle];
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST) || GNU_GUI_LIBRARY
+  [_attributes_tableView setUsesAlternatingRowBackgroundColors:YES];
+  [_attributes_tableView setGridStyleMask:NSTableViewSolidVerticalGridLineMask];
+#endif
   [_attributes_tableView setAllowsMultipleSelection:YES];
   [_attributes_tableView setAllowsEmptySelection:YES];
 
@@ -102,11 +126,11 @@
   [_attributes_dg setDelegate:self];
 
   [self setupCornerView:cornerView
-	  tableView:_attributes_tableView
-	  displayGroup:_attributes_dg 
-	  forClass:[EOAttribute class]];
+          tableView:_attributes_tableView
+          displayGroup:_attributes_dg 
+          forClass:[EOAttribute class]];
   [self addDefaultTableColumnsForTableView:_attributes_tableView 
-	  		displayGroup:_attributes_dg];
+                          displayGroup:_attributes_dg];
   
   /* setup the relationships table view */ 
   scrollView = [[NSScrollView alloc] initWithFrame:NSMakeRect(0,0,100,100)];
@@ -114,7 +138,18 @@
   [scrollView setHasHorizontalScroller:YES];
   [scrollView setHasVerticalScroller:YES];
   _relationships_tableView = [[NSTableView alloc] initWithFrame:NSMakeRect(0,0,100,100)];
+
+#if OS_API_VERSION(GS_API_NONE, MAC_OS_X_VERSION_10_4)
   [_relationships_tableView setAutoresizesAllColumnsToFit:NO];
+#else
+  [_relationships_tableView setColumnAutoresizingStyle:NSTableViewLastColumnOnlyAutoresizingStyle];
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST) || GNU_GUI_LIBRARY
+  [_relationships_tableView setUsesAlternatingRowBackgroundColors:YES];
+  [_relationships_tableView setGridStyleMask:NSTableViewSolidVerticalGridLineMask];
+#endif
+
   [_relationships_tableView setAllowsMultipleSelection:YES];
   [_relationships_tableView setAllowsEmptySelection:YES];
   [scrollView setDocumentView:_relationships_tableView];
@@ -146,12 +181,12 @@
   [_relationships_dg setDelegate:self];
   
   [self setupCornerView:cornerView
-	  tableView:_relationships_tableView
-	  displayGroup:_relationships_dg 
-	  forClass:[EORelationship class]];
+          tableView:_relationships_tableView
+          displayGroup:_relationships_dg 
+          forClass:[EORelationship class]];
 
   [self addDefaultTableColumnsForTableView:_relationships_tableView 
-	  		displayGroup:_relationships_dg];
+                          displayGroup:_relationships_dg];
   
   return self;
 }
@@ -213,12 +248,12 @@
   
   if (![[_attributes_dg selectedObjects] isEqual:selWithin]
       && ![_attributes_dg selectObjectsIdenticalTo:selWithin
-	  			selectFirstOnNoMatch:NO])
+                                  selectFirstOnNoMatch:NO])
     [_attributes_dg clearSelection];
   
   if (![[_relationships_dg selectedObjects] isEqual:selWithin]
       && ![_relationships_dg selectObjectsIdenticalTo:selWithin
-  				selectFirstOnNoMatch:NO])
+                                  selectFirstOnNoMatch:NO])
     [_relationships_dg clearSelection];
 }
 
@@ -230,11 +265,11 @@
 - (void) objectWillChange:(id)sender
 {
   [[NSRunLoop currentRunLoop]
-	  performSelector:@selector(needToFetch:) 
-	  	   target:self
-		 argument:nil
-		    order:999 /* this number is probably arbitrary */
-		    modes:[NSArray arrayWithObject:NSDefaultRunLoopMode]];
+          performSelector:@selector(needToFetch:) 
+                   target:self
+                 argument:nil
+                    order:999 /* this number is probably arbitrary */
+                    modes:[NSArray arrayWithObject:NSDefaultRunLoopMode]];
 }
 
 - (NSArray *)defaultColumnNamesForClass:(Class)aClass
@@ -243,11 +278,11 @@
   if (colNames == nil || [colNames count] == 0)
     {
       if (aClass == [EOAttribute class])
-	return DefaultAttributeColumns; 
+        return DefaultAttributeColumns; 
       else if (aClass == [EORelationship class])
-	return DefaultRelationshipColumns;
+        return DefaultRelationshipColumns;
       else
-	return nil;
+        return nil;
     }
     
   return colNames;
