@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -31,10 +31,15 @@
 
 #include <EOInterface/EODisplayGroup.h>
 #include <EOAccess/EOEntity.h>
+#include <EOAccess/EOModel.h>
+#include <EOControl/EOEditingContext.h>
 #include <EOControl/EOObserver.h>
 #include <EOModeler/EOModelerApp.h>
 #include <EOModeler/EOModelerDocument.h>
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSImage.h>
 #include <AppKit/NSSplitView.h>
 #include <AppKit/NSScrollView.h>
@@ -44,6 +49,10 @@
 #include <AppKit/NSMenuItem.h>
 #include <AppKit/NSPopUpButton.h>
 #include <AppKit/NSPopUpButtonCell.h>
+#endif
+
+#include <GNUstepBase/GNUstep.h>
+#include <GNUstepBase/GSVersionMacros.h>
 
 @interface EOModelerDocument (asdf)
 -(void)_setDisplayGroup:(id)displayGroup;
@@ -101,7 +110,18 @@
 
       _topTable = [[NSTableView alloc] initWithFrame:NSMakeRect(0,0,10,10)];
       _bottomTable = [[NSTableView alloc] initWithFrame:NSMakeRect(0,0,10,10)];
+
+#if OS_API_VERSION(GS_API_NONE, MAC_OS_X_VERSION_10_4)
       [_topTable setAutoresizesAllColumnsToFit:NO];
+#else
+      [_topTable setColumnAutoresizingStyle:NSTableViewLastColumnOnlyAutoresizingStyle];
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST) || GNU_GUI_LIBRARY
+      [_topTable setUsesAlternatingRowBackgroundColors:YES];
+      [_topTable setGridStyleMask:NSTableViewSolidVerticalGridLineMask];
+#endif
+
       [scrollView setDocumentView:_topTable];
       RELEASE(_topTable);
       [_splitView addSubview:scrollView];
@@ -111,7 +131,18 @@
       [scrollView setHasHorizontalScroller:YES];
       [scrollView setHasVerticalScroller:YES];
       [scrollView setBorderType: NSBezelBorder];
+
+#if OS_API_VERSION(GS_API_NONE, MAC_OS_X_VERSION_10_4)
       [_bottomTable setAutoresizesAllColumnsToFit:NO];
+#else
+      [_bottomTable setColumnAutoresizingStyle:NSTableViewLastColumnOnlyAutoresizingStyle];
+#endif
+
+#if OS_API_VERSION(MAC_OS_X_VERSION_10_3, GS_API_LATEST) || GNU_GUI_LIBRARY
+      [_bottomTable setUsesAlternatingRowBackgroundColors:YES];
+      [_bottomTable setGridStyleMask:NSTableViewSolidVerticalGridLineMask];
+#endif
+
       [scrollView setDocumentView:_bottomTable];
       RELEASE(_bottomTable);
       [_splitView addSubview:scrollView];
@@ -143,8 +174,8 @@
       
       classDescription = nil; 
       wds = [[KVDataSource alloc]
-	      initWithClassDescription:classDescription 
-  			editingContext:[[self document] editingContext]];
+              initWithClassDescription:classDescription 
+                        editingContext:[[self document] editingContext]];
   
       [wds setDataObject: [[self document] model]];
       [wds setKey:@"entities"];
@@ -156,12 +187,12 @@
       [dg setDelegate: self]; 
       
       [self setupCornerView:cornerView
-	  tableView:_topTable
-	  displayGroup:dg
-	  forClass:[EOEntity class]];
+          tableView:_topTable
+          displayGroup:dg
+          forClass:[EOEntity class]];
   
       [self addDefaultTableColumnsForTableView:_topTable
-	  		displayGroup:dg];
+                                  displayGroup:dg];
 
       
     }
@@ -186,7 +217,7 @@
   [dg fetch];
 
   [dg selectObjectsIdenticalTo:[self selectionWithinViewedObject]
-	  selectFirstOnNoMatch:NO];
+          selectFirstOnNoMatch:NO];
 }
 
 - (NSView *)mainView
@@ -197,11 +228,11 @@
 - (void) objectWillChange:(id)anObject
 {
   [[NSRunLoop currentRunLoop]
-	  performSelector:@selector(needToFetch:)
-	  	   target:self
-		 argument:nil
-		    order:999 /* this number is probably arbitrary */
-		    modes:[NSArray arrayWithObject:NSDefaultRunLoopMode]];
+          performSelector:@selector(needToFetch:)
+                   target:self
+                 argument:nil
+                    order:999 /* this number is probably arbitrary */
+                    modes:[NSArray arrayWithObject:NSDefaultRunLoopMode]];
 }
 
 - (void) needToFetch:(id)sth
