@@ -11,7 +11,7 @@
 
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -25,7 +25,13 @@
 */ 
 
 #include <EOModeler/EOModelerEditor.h>
+
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSMenuItem.h>
+#endif
+
 @class EODisplayGroup;
 @class NSPopUpButton;
 @class NSTableView;
@@ -34,18 +40,18 @@
  */
 @interface ModelerTableEmbedibleEditor : EOModelerEmbedibleEditor
 - (void) setupCornerView:(NSPopUpButton *)cornerView
-		tableView:(NSTableView *)tableView
-		displayGroup:(EODisplayGroup *)dg
-		forClass:(Class)aClass;
+               tableView:(NSTableView *)tableView
+            displayGroup:(EODisplayGroup *)dg
+                forClass:(Class)aClass;
 
 - (void) _cornerAction:(id)sender;
 - (NSArray *)defaultColumnNamesForClass:(Class)aClass;
 - (void) addDefaultTableColumnsForTableView:(NSTableView *)tv
-		displayGroup:(EODisplayGroup *)dg;
+                               displayGroup:(EODisplayGroup *)dg;
 - (void) addTableColumnForItem:(NSMenuItem <NSMenuItem>*)item
-	  tableView:(NSTableView *)tv;
+                     tableView:(NSTableView *)tv;
 - (void) removeTableColumnForItem:(NSMenuItem <NSMenuItem>*)menuItem
-	  tableView:(NSTableView *)tv;
+                        tableView:(NSTableView *)tv;
 
 @end
 
