@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -26,22 +26,29 @@
 
 #include "ModelerTableEmbedibleEditor.h"
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSMenuItem.h>
 #include <AppKit/NSPopUpButton.h>
 #include <AppKit/NSTableColumn.h>
 #include <AppKit/NSTableView.h>
 #include <AppKit/NSScrollView.h>
 #include <AppKit/NSImage.h>
+#endif
 
 #include <EOInterface/EODisplayGroup.h>
 #include <EOInterface/EOAssociation.h>
 #include "EOModeler/EOModelerApp.h"
+
+#include <GNUstepBase/GNUstep.h>
+
 /* base class with some methods shared among default embedible editors */
 @implementation ModelerTableEmbedibleEditor : EOModelerEmbedibleEditor
 - (void) setupCornerView:(NSPopUpButton *)cornerView
-		tableView:(NSTableView *)tableView
-		displayGroup:(EODisplayGroup *)dg
-		forClass:(Class)aClass
+               tableView:(NSTableView *)tableView
+            displayGroup:(EODisplayGroup *)dg
+                forClass:(Class)aClass
 {
   NSArray *columnNames = [EOMApp columnNamesForClass:aClass];
   int i, c;
@@ -70,7 +77,7 @@
 }
 
 - (void) addDefaultTableColumnsForTableView:(NSTableView *)tv
-			       displayGroup:(EODisplayGroup *)dg
+                               displayGroup:(EODisplayGroup *)dg
 {
   Class aClass = [[(NSPopUpButton*)[tv cornerView] cell] representedObject];
   NSArray *columnNames = [self defaultColumnNamesForClass:aClass];
@@ -91,7 +98,7 @@
       RELEASE(tc);
       
       [provider initColumn:tc class:aClass name:columnName
-	      displayGroup:dg document:[self document]]; 
+              displayGroup:dg document:[self document]]; 
       item = (NSMenuItem *)[cv itemWithTitle:columnName];
       [item setRepresentedObject:tc];
       [item setState:NSOnState];
@@ -100,7 +107,7 @@
 }
 
 - (void) addTableColumnForItem:(NSMenuItem <NSMenuItem>*)item
-	  tableView:(NSTableView *)tv
+          tableView:(NSTableView *)tv
 {
   NSString *columnName = [item title];
   Class aClass = [[(NSPopUpButton *)[tv cornerView] cell] representedObject];
@@ -116,16 +123,16 @@
   /* this requires that the table at least have 1 table column in it...
    * so we have to have another method to setup the default table columns */
   [provider initColumn:tc
-	  class:aClass
+          class:aClass
            name:columnName
    displayGroup:[[tv delegate] displayGroupForAspect:@"source"] // <-+-^
        document:[self document]];
   [tc sizeToFit]; 
   [tv tile];
 }
-	  
+          
 - (void) removeTableColumnForItem:(NSMenuItem <NSMenuItem>*)item
-	  tableView:(NSTableView *)tv
+          tableView:(NSTableView *)tv
 {
   [tv removeTableColumn:[item representedObject]];
   [item setRepresentedObject:nil];
@@ -147,11 +154,11 @@
 }
 
 - (void) displayGroup:(EODisplayGroup *)dg didSetValue:(id)value
-	    forObject:(id)obj key:(NSString *)key
+            forObject:(id)obj key:(NSString *)key
 {
   [[NSNotificationCenter defaultCenter]
-	  postNotificationName:EOMSelectionChangedNotification
-	  object:nil];
+          postNotificationName:EOMSelectionChangedNotification
+          object:nil];
 }
 
 @end
