@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -22,7 +22,12 @@
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
     </license>
 **/
+
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSView.h>
+#endif
 
 @interface NSView (Additions)
 - (void) orderViewFront:(NSView *)v;
