@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -23,9 +23,19 @@
     </license>
 **/
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSObject.h>
-#include <AppKit/NSNibDeclarations.h>
+#endif
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
+#include <AppKit/NSNibDeclarations.h>
+#endif
+
+@class NSArray;
 @class NSWindow;
 @class NSButton;
 @class NSTableView;
