@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -26,14 +26,25 @@
 #include "SQLGenerator.h"
 #include "Modeler.h"
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSException.h>
 #include <Foundation/NSDictionary.h>
+#endif
+
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSNibLoading.h>
 
 #include <AppKit/NSButton.h>
 #include <AppKit/NSTextView.h>
 #include <AppKit/NSSavePanel.h>
 #include <AppKit/NSWindow.h>
+#endif
+
+#include <Renaissance/Renaissance.h>
 
 #include <EOAccess/EOAdaptor.h>
 #include <EOAccess/EOAdaptorChannel.h>
@@ -44,6 +55,8 @@
 #include <EOModeler/EOModelerApp.h>
 #include <EOModeler/EOModelerDocument.h>
 
+#include <GNUstepBase/GNUstep.h>
+
 static SQLGenerator *sharedGenerator;
 static BOOL loadedNib;
 static BOOL goodToGo;
@@ -66,19 +79,19 @@ static NSString *_otherScript;
   if (sharedGenerator)
     {
       [[NSException exceptionWithName:NSInternalInconsistencyException
-	    		reason: @"singleton initialized multiple times"
-			userInfo:nil] raise];
+                               reason: @"singleton initialized multiple times"
+                             userInfo:nil] raise];
       return nil;
     }
   self = [super init];
   adminSwitchButtons = [[NSMutableArray alloc] initWithCapacity:3];
   otherSwitchButtons = [[NSMutableArray alloc] initWithCapacity:7];
   opts = [[NSMutableDictionary alloc] initWithCapacity:8];
-  loadedNib = [NSBundle loadNibNamed:@"SQLGenerator" owner:self];
+  loadedNib = [NSBundle loadGSMarkupNamed: @"SQLGenerator" owner: self];
   return self;
 }
 
-- (void) awakeFromNib
+- (void) awakeFromGSMarkup
 {
   [[dropDatabaseSwitch cell] setRepresentedObject: EODropDatabaseKey];
   [[createDatabaseSwitch cell] setRepresentedObject: EOCreateDatabaseKey];
@@ -144,16 +157,16 @@ static NSString *_otherScript;
       connDict = [adaptor runLoginPanel];
 
       if (connDict)
-	[adaptor setConnectionDictionary:connDict];
+        [adaptor setConnectionDictionary:connDict];
     }
  
   if (!adaptor || [[connDict allKeys] count] == 0)
     {
       NSRunAlertPanel(@"Error",
-		      @"SQL generator requires a valid adaptor and connection dictionary",
-		      @"Ok",
-		      nil,
-		      nil);
+                      @"SQL generator requires a valid adaptor and connection dictionary",
+                      @"Ok",
+                      nil,
+                      nil);
       return;
     }
 
@@ -260,7 +273,7 @@ static NSString *_otherScript;
      {
        btn = [adminSwitchButtons objectAtIndex:i];
        [opts setObject:([[btn objectValue] boolValue]) ? @"YES" : @"NO"
- 		forKey: [[btn cell] representedObject]];
+                forKey: [[btn cell] representedObject]];
      }
   
   for (i = 0, c = [otherSwitchButtons count]; i < c; i++)
@@ -271,7 +284,7 @@ static NSString *_otherScript;
   
   arr = [[[EOMApp activeDocument] model] entities];
   _adminScript = RETAIN([expr schemaCreationScriptForEntities:arr
-	  				options:opts]);
+                                          options:opts]);
 
   for (i = 0, c = [adminSwitchButtons count]; i < c; i++)
      {
@@ -283,12 +296,12 @@ static NSString *_otherScript;
      {
        btn = [otherSwitchButtons objectAtIndex:i];
        [opts setObject:([[btn objectValue] boolValue]) ? @"YES" : @"NO"
-	            forKey: [[btn cell] representedObject]];
+                    forKey: [[btn cell] representedObject]];
      }
   
   arr = [[[EOMApp activeDocument] model] entities];
   _otherScript = RETAIN([expr schemaCreationScriptForEntities:arr
-	  				options:opts]);
+                                          options:opts]);
   
   [_sqlOutput setString:[_adminScript stringByAppendingString:_otherScript]];
 }
