@@ -9,7 +9,7 @@
     <license>
     DBModeler is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     DBModeler is distributed in the hope that it will be useful,
@@ -24,16 +24,38 @@
 **/
 
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSAutoreleasePool.h>
+#endif
+
 #include <EOModeler/EOModelerApp.h>
 #include "Modeler.h"
 
+#include <Renaissance/Renaissance.h>
+
+#include <GNUstepBase/GNUstep.h>
+
+
+// required for windows.
+int (*linkRenaissanceIn)(int, const char **) = GSMarkupApplicationMain; 
+
 int main (int argc, const char **argv)
 {
+  Modeler *m;
   NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
  
   [EOModelerApp sharedApplication];
-  [NSApp setDelegate: [[Modeler alloc] init]];
+  m = [[Modeler alloc] init];
+  [NSApp setDelegate: m];
+
+#ifdef NeXT_GUI_LIBRARY
+  [NSBundle loadGSMarkupNamed: @"Menu-Cocoa" owner: m];
+#else
+  [NSBundle loadGSMarkupNamed: @"Menu-GNUstep" owner: m];
+#endif
+
   [NSApp run];
   RELEASE(pool);
   return 0;
