@@ -9,8 +9,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 24302 $
-   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
+   $Revision: 26323 $
+   $Date: 2008-03-16 23:59:56 +0100 (Son, 16. Mär 2008) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAdaptor.m 24302 2007-01-01 11:52:38Z ayers $")
+RCS_ID("$Id: EOAdaptor.m 26323 2008-03-16 22:59:56Z ratmice $")
 
 #if HAVE_LIBC_H
 # include <libc.h>
@@ -52,7 +52,6 @@ RCS_ID("$Id: EOAdaptor.m 24302 2007-01-01 11:52:38Z ayers $")
 #include <Foundation/NSPathUtilities.h>
 #include <Foundation/NSBundle.h>
 #include <Foundation/NSObjCRuntime.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSValue.h>
 #include <Foundation/NSProcessInfo.h>
 #include <Foundation/NSException.h>
@@ -75,13 +74,13 @@ RCS_ID("$Id: EOAdaptor.m 24302 2007-01-01 11:52:38Z ayers $")
 #include <EOControl/EONSAddOns.h>
 #include <EOControl/EODebug.h>
 
-#include <EOAccess/EOAdaptor.h>
-#include <EOAccess/EOAdaptorContext.h>
-#include <EOAccess/EOAdaptorChannel.h>
-#include <EOAccess/EOAttribute.h>
-#include <EOAccess/EOEntity.h>
-#include <EOAccess/EOModel.h>
-#include <EOAccess/EOSQLExpression.h>
+#include "EOAccess/EOAdaptor.h"
+#include "EOAccess/EOAdaptorContext.h"
+#include "EOAccess/EOAdaptorChannel.h"
+#include "EOAccess/EOAttribute.h"
+#include "EOAccess/EOEntity.h"
+#include "EOAccess/EOModel.h"
+#include "EOAccess/EOSQLExpression.h"
 
 #include "EOAdaptorPriv.h"
 
@@ -115,7 +114,9 @@ static struct { NSString *name; NSStringEncoding encoding; } encodingMap[] = {
   { @"NSWindowsCP1250StringEncoding", NSWindowsCP1250StringEncoding },
   { @"NSISO2022JPStringEncoding",     NSISO2022JPStringEncoding },
   { @"NSMacOSRomanStringEncoding",    NSMacOSRomanStringEncoding },
+#if defined(GNUSTEP_BASE_LIBRARY) || OS_API_VERSION(GS_API_NONE,MAC_OS_X_VERSION_10_5)
   { @"NSProprietaryStringEncoding",   NSProprietaryStringEncoding },
+#endif
   { @"NSKOI8RStringEncoding",         NSKOI8RStringEncoding }, 
   { @"NSISOLatin3StringEncoding",     NSISOLatin3StringEncoding },
   { @"NSISOLatin4StringEncoding",     NSISOLatin4StringEncoding },
