@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 24297 $
-   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
+   $Revision: 26597 $
+   $Date: 2008-06-06 11:26:14 +0200 (Fre, 06. Jun 2008) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,23 +36,23 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
+RCS_ID("$Id: EOAttribute.m 26597 2008-06-06 09:26:14Z ayers $")
 
 #include <ctype.h>
 #include <string.h>
 
 #ifdef GNUSTEP
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSArchiver.h>
-#include <Foundation/NSObjCRuntime.h>
-#include <Foundation/NSException.h>
-#include <Foundation/NSTimeZone.h>
-#include <Foundation/NSData.h>
-#include <Foundation/NSInvocation.h>
-#include <Foundation/NSDecimalNumber.h>
-#include <Foundation/NSValue.h>
 #include <Foundation/NSCalendarDate.h>
-#include <Foundation/NSDebug.h>
+#include <Foundation/NSData.h>
+#include <Foundation/NSDecimalNumber.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
+#include <Foundation/NSInvocation.h>
+#include <Foundation/NSObjCRuntime.h>
+#include <Foundation/NSTimeZone.h>
+#include <Foundation/NSValue.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -109,19 +109,15 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
       NSString *tmpString = nil;
       id tmpObject = nil;
 
-      [self setName: [propertyList objectForKey: @"name"]];
-
-      EOFLOGObjectLevelArgs(@"gsdb", @"Attribute parent=%p %@",
-		   owner, [(EOEntity *)owner name]);
-
+      // set this first so the name can validate against the parent.
       [self setParent: owner];
-//      EOFLOGObjectLevel(@"gsdb", @"Attribute Entity=%@", [self entity]);
+      [self setName: [propertyList objectForKey: @"name"]];
 
       [self setExternalType: [propertyList objectForKey: @"externalType"]];
 
       tmpString = [propertyList objectForKey: @"allowsNull"];
       if (tmpString)
-        [self setAllowsNull: [tmpString isEqual: @"Y"]];
+        [self setAllowsNull: [tmpString boolValue]];
 
       [self setValueType: [propertyList objectForKey: @"valueType"]];
       [self setValueClassName: [propertyList objectForKey: @"valueClassName"]];
@@ -197,23 +193,17 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
       tmpString = [propertyList objectForKey: @"parameterDirection"];
       if (tmpString)
         {
-	  if ([tmpString isKindOfClass: GDL2_NSNumberClass])
-	    {
-	      [self setParameterDirection: [tmpString intValue]];
-	    }
-	  else
-	    {
-	      EOParameterDirection eDirection = EOVoid;
+	  EOParameterDirection tmpDir = [tmpString intValue];
+	  EOParameterDirection eDirection = EOVoid;
 
-	      if ([tmpString isEqual: @"in"])
-		eDirection = EOInParameter;
-	      else if ([tmpString isEqual: @"out"])
-		eDirection = EOOutParameter;
-	      else if ([tmpString isEqual: @"inout"])
-		eDirection = EOInOutParameter;
+	  if ([tmpString isEqual: @"in"] || tmpDir == EOInParameter)
+ 	    eDirection = EOInParameter;
+	  else if ([tmpString isEqual: @"out"] || tmpDir == EOOutParameter)
+ 	    eDirection = EOOutParameter;
+	  else if ([tmpString isEqual: @"inout"] || tmpDir == EOInOutParameter)
+	    eDirection = EOInOutParameter;
 
-	      [self setParameterDirection: eDirection];
-	    }
+	  [self setParameterDirection: eDirection];
         }
 
       tmpObject = [propertyList objectForKey: @"userInfo"];
@@ -238,13 +228,9 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
       if (tmpString)
         [self setDocComment: tmpString];
 
-      EOFLOGObjectLevelArgs(@"gsdb", @"Attribute name=%@", _name);
-
       tmpString = [propertyList objectForKey: @"isReadOnly"];
-      EOFLOGObjectLevelArgs(@"gsdb", @"tmpString=%@", tmpString);
 
-      [self setReadOnly: [tmpString isEqual: @"Y"]];
-      EOFLOGObjectLevelArgs(@"gsdb", @"tmpString=%@", tmpString);
+      [self setReadOnly: [tmpString boolValue]];
     }
 
   return self;
@@ -753,7 +739,7 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
 					  name,
 					  *p]
 			userInfo: nil];
-      if ([[self entity] attributeNamed:name])
+      if ([[self entity] _hasAttributeNamed:name])
 	exc++;
       else if ((storedProcedures = [[[self entity] model] storedProcedures]))
         {
@@ -804,11 +790,10 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
 
       oldName = AUTORELEASE(RETAIN(_name));
       [self willChange];
-      ASSIGN(_name, name);
+      ASSIGNCOPY(_name, name);
       if (_flags.isParentAnEOEntity)
 	{
 	  [_parent _setIsEdited];
-	  [_parent _attributeNameChangedFrom: oldName to: name];
 	}
     }
 
@@ -825,7 +810,7 @@ RCS_ID("$Id: EOAttribute.m 24297 2006-12-30 17:41:02Z ayers $")
   //seems OK
   [self willChange];
 
-  ASSIGN(_columnName, columnName);
+  ASSIGNCOPY(_columnName, columnName);
   DESTROY(_definitionArray);
 
   [_parent _setIsEdited];
@@ -878,14 +863,24 @@ return nexexp
   return definition;
 }
 
+/**
+ * <p>Sets the definition of a derived attribute.</p>
+ * <p>An EOAttribute can either reference column from the entites
+ * external representation or define a derived attribute such a
+ * cacluclated value or a key path.  The values to these attributes
+ * are cached in memory.<p>
+ * <p>To set the definition of an attribute, the attribute must
+ * already be contained by its parent entity.</p>
+ * <p>Setting the the definition clears the column name.</p>
+ */
 - (void)setDefinition:(NSString *)definition
 {
   if(definition)
     {
       [self willChange];
       [self _setDefinitionWithoutFlushingCaches: definition];
+      DESTROY(_columnName);
       [_parent _setIsEdited];
-      DESTROY(_columnName);//??
     }
 }
 
@@ -907,7 +902,7 @@ return nexexp
   //OK
   [self willChange];
 
-  ASSIGN(_externalType, type);
+  ASSIGNCOPY(_externalType, type);
 
   [_parent _setIsEdited];
   [self _setOverrideForKeyEnum: 0];//TODO
@@ -918,7 +913,7 @@ return nexexp
   //OK
   [self willChange];
 
-  ASSIGN(_valueType, type);
+  ASSIGNCOPY(_valueType, type);
 
   if ([_valueType length]==1)
     _valueTypeCharacter = [_valueType characterAtIndex:0];
@@ -932,7 +927,7 @@ return nexexp
 {
   [self willChange];
 
-  ASSIGN(_valueClassName, name);
+  ASSIGNCOPY(_valueClassName, name);
 
   _valueClass = NSClassFromString(_valueClassName);
 
@@ -972,13 +967,13 @@ return nexexp
 - (void)setWriteFormat: (NSString *)string
 {
   [self willChange];
-  ASSIGN(_writeFormat, string);
+  ASSIGNCOPY(_writeFormat, string);
 }
 
 - (void)setReadFormat: (NSString *)string
 {
   [self willChange];
-  ASSIGN(_readFormat, string);
+  ASSIGNCOPY(_readFormat, string);
 }
 
 - (void)setParameterDirection: (EOParameterDirection)parameterDirection
@@ -1011,7 +1006,7 @@ return nexexp
 {
   //OK
   [self willChange];
-  ASSIGN(_docComment, docComment);
+  ASSIGNCOPY(_docComment, docComment);
   [_parent _setIsEdited];
 }
 
@@ -1546,7 +1541,7 @@ See also: -setFactoryMethodArgumentType:
 - (void)setValueFactoryMethodName: (NSString *)factoryMethodName
 {
   [self willChange];
-  ASSIGN(_valueFactoryMethodName, factoryMethodName);
+  ASSIGNCOPY(_valueFactoryMethodName, factoryMethodName);
   _valueFactoryMethod = NSSelectorFromString(_valueFactoryMethodName);
 }
 
@@ -1560,7 +1555,7 @@ See also: -setFactoryMethodArgumentType:
 - (void)setAdaptorValueConversionMethodName: (NSString *)conversionMethodName
 {
   [self willChange];
-  ASSIGN(_adaptorValueConversionMethodName, conversionMethodName);
+  ASSIGNCOPY(_adaptorValueConversionMethodName, conversionMethodName);
 
   _adaptorValueConversionMethod 
     = NSSelectorFromString(_adaptorValueConversionMethodName);
