@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: June 2000
 
-   $Revision: 24302 $
-   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
+   $Revision: 25994 $
+   $Date: 2008-01-22 14:57:07 +0100 (Die, 22. Jän 2008) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,18 +33,18 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EODatabase.m 24302 2007-01-01 11:52:38Z ayers $")
+RCS_ID("$Id: EODatabase.m 25994 2008-01-22 13:57:07Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
+#include <Foundation/NSDebug.h>
 #include <Foundation/NSDictionary.h>
-#include <Foundation/NSString.h>
+#include <Foundation/NSEnumerator.h>
 #include <Foundation/NSException.h>
-#include <Foundation/NSValue.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSSet.h>
-#include <Foundation/NSDebug.h>
+#include <Foundation/NSString.h>
+#include <Foundation/NSValue.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
