@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: December 2001
 
-   $Revision: 23510 $
-   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
+   $Revision: 26323 $
+   $Date: 2008-03-16 23:59:56 +0100 (Son, 16. Mär 2008) $
 
    <abstract></abstract>
 
@@ -22,7 +22,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,7 +38,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EODatabaseDataSource.m 23510 2006-09-14 16:06:21Z ayers $")
+RCS_ID("$Id: EODatabaseDataSource.m 26323 2008-03-16 22:59:56Z ratmice $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -193,7 +193,6 @@ RCS_ID("$Id: EODatabaseDataSource.m 23510 2006-09-14 16:06:21Z ayers $")
 {
   EOObjectStore *store;
   NSString *entityName = [_fetchSpecification entityName];
-  static SEL modelGroupSel = @selector(modelGroup);
   EOModelGroup *modelGroup = nil;
   
   store = [_editingContext rootObjectStore];
@@ -219,9 +218,9 @@ RCS_ID("$Id: EODatabaseDataSource.m 23510 2006-09-14 16:06:21Z ayers $")
 	}
       return nil;
     }
-  else if ([store respondsToSelector:modelGroupSel])
+  else if ([store respondsToSelector:@selector(modelGroup:)])
     {
-      modelGroup = [store performSelector:modelGroupSel];
+      modelGroup = [store performSelector:@selector(modelGroup:)];
     }
   
   if (modelGroup != nil)
