@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -116,8 +116,7 @@
     unsigned int isAbstractEntity:1;
     unsigned int updating:1;
     unsigned int cachesObjects:1;
-
-    unsigned int createsMutableObjects:1;
+    unsigned int unused:1;
 
     unsigned int extraRefCount:22;
   } _flags;
