@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,16 +34,10 @@
 @class EOExpressionArray;
 @class EOSQLExpression;
 
-GDL2ACCESS_EXPORT void GDL2DestinationEntitiesAddRelationship(EOEntity *entity, EORelationship *relationship);
-GDL2ACCESS_EXPORT void GDL2DestinationEntitiesRemoveRelationship(EOEntity *entity, EORelationship *relationship);
-
 @interface EOEntity (EOEntityPrivate)
 
 - (BOOL)isPrototypeEntity;
 
-- (void)setCreateMutableObjects: (BOOL)flag;
-- (BOOL)createsMutableObjects;
-
 - (void)_setModel: (EOModel *)model;
 - (void)_setParentEntity: (EOEntity *)parent;
 
@@ -90,12 +84,12 @@ GDL2ACCESS_EXPORT void GDL2DestinationEntitiesRemoveRelationship(EOEntity *entit
 - (EOMKKDInitializer *)_propertyDictionaryInitializer;
 - (EOMKKDInitializer *)_instanceDictionaryInitializer;
 - (void)_setIsEdited;
-- (void)_attributeNameChangedFrom: (NSString *)oldName to: (NSString *)newName;
 - (NSArray *)_classPropertyAttributes;
 
 - (Class)classForObjectWithGlobalID: (EOKeyGlobalID *)globalID;
 - (id)globalIDForRow: (NSDictionary *)row
 	     isFinal: (BOOL)isFinal;
+- (BOOL) _hasAttributeNamed:(NSString *)name;
 @end
 
 @interface EOEntity (EOEntityRelationshipPrivate)
