@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 23874 $
-   $Date: 2006-10-15 14:23:42 +0200 (Son, 15 Okt 2006) $
+   $Revision: 27695 $
+   $Date: 2009-01-26 13:05:29 +0100 (Mon, 26. Jän 2009) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,11 +33,10 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOJoin.m 23874 2006-10-15 12:23:42Z ratmice $")
+RCS_ID("$Id: EOJoin.m 27695 2009-01-26 12:05:29Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSDebug.h>
 #else
 #include <Foundation/Foundation.h>
@@ -81,6 +80,13 @@ RCS_ID("$Id: EOJoin.m 23874 2006-10-15 12:23:42Z ratmice $")
   return self;
 }
 
+- (void)dealloc
+{
+  DESTROY(_sourceAttribute);
+  DESTROY(_destinationAttribute);
+  [super dealloc];
+}
+
 - (unsigned)hash
 {
   return [_sourceAttribute hash];
