@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,7 +71,7 @@
   //NSMutableDictionary *_prototypesByName;
   struct
   {
-    BOOL createsMutableObjects:1;
+    BOOL unused:1;
     BOOL errors:1;
   } _flags;
 }
