@@ -7,8 +7,8 @@
            Manuel Guesdon <mguesdon@orange-concept.com>
    Date: February 2000
 
-   $Revision: 24302 $
-   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
+   $Revision: 26594 $
+   $Date: 2008-06-06 01:14:14 +0200 (Fre, 06. Jun 2008) $
 
    <abstract></abstract>
 
@@ -18,7 +18,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,12 +34,11 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOModel.m 24302 2007-01-01 11:52:38Z ayers $")
+RCS_ID("$Id: EOModel.m 26594 2008-06-05 23:14:14Z ratmice $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSBundle.h>
 #include <Foundation/NSValue.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSObjCRuntime.h>
 #include <Foundation/NSException.h>
 #include <Foundation/NSFileManager.h>
@@ -88,8 +87,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 
 + (NSString *) _formatModelPath: (NSString *)path checkFileSystem: (BOOL)chkFS;
 
-- (void) setCreateMutableObjects: (BOOL)flag;
-- (BOOL) createsMutableObjects;
 - (EOEntity *) _verifyBuiltEntityObject: (id)entity
                                   named: (NSString *)name;
 
@@ -209,7 +206,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
     {
       // Turbocat
       _version = DEFAULT_MODEL_VERSION;
-      _flags.createsMutableObjects = YES;
       
       _entitiesByName = [NSMutableDictionary new];
       _entitiesByClass = NSCreateMapTableWithZone(NSObjectMapKeyCallBacks, 
@@ -909,7 +905,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
           propListSt = [propertyList objectForKey: @"storedProcedures"];
       
           _flags.errors = NO;
-          [self setCreateMutableObjects: YES];
       
           count = [propListEntities count];
           for (i = 0; i < count; i++)
@@ -994,8 +989,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
               while ((sp = [enumerator nextObject]))
                 [sp awakeWithPropertyList: [markSP objectForKey: [sp name]]];
             }
-  
-          [self setCreateMutableObjects: NO];
         }
     }
   NS_HANDLER
@@ -1365,6 +1358,9 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSAssert(entityName, @"No entity name");
   NSAssert(className, @"No class name");
 
+  NSAssert1([_entitiesByName objectForKey: entityName] == nil,
+	    @"Entity '%@' is already registered with this model",
+	    entityName);
   //Seems OK
   [_entitiesByName setObject: entity
                    forKey: entityName];
@@ -1396,7 +1392,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 	}
 
       [self willChange];
-      ASSIGN(_name, name);
+      ASSIGNCOPY(_name, name);
 
       if (group)
 	{
@@ -1408,7 +1404,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 - (void) setAdaptorName: (NSString *)adaptorName
 {
   [self willChange];
-  ASSIGN(_adaptorName, adaptorName);
+  ASSIGNCOPY(_adaptorName, adaptorName);
 }
 
 - (void) setConnectionDictionary: (NSDictionary *)connectionDictionary
@@ -1426,7 +1422,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 - (void) setDocComment: (NSString *)docComment
 {
   [self willChange];
-  ASSIGN(_docComment, docComment);
+  ASSIGNCOPY(_docComment, docComment);
 }
 
 - (void) addEntity: (EOEntity *)entity
@@ -1437,7 +1433,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSString *className = nil;
 
   NSAssert1([self entityNamed: [entity name]] == nil,
-	    @"Entity '%@' already registered as with this model",
+	    @"Entity '%@' is already registered with this model",
 	    entityName);
 
   NSAssert2([entity model]==nil,
@@ -1445,16 +1441,9 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
 	    [entity name], [[entity model] name]);
 
   [self willChange];
+  
   /* Do not access _entities until cache is triggered */
-  if ([self createsMutableObjects])
-    [(NSMutableArray *)[self entities] addObject: entity];
-  else
-    {
-      id e = [NSMutableArray arrayWithArray: [self entities]];
-
-      [e addObject: entity];
-      ASSIGNCOPY(_entities, e);
-    }
+  [(NSMutableArray *)[self entities] addObject: entity];
 
   NSAssert(_entitiesByClass, @"No _entitiesByClass");
 
@@ -1487,15 +1476,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSMapRemove(_entitiesByClass, className);
 
   /* Do not access _entities until cache is triggered */
-  if ([self createsMutableObjects])
-    [(NSMutableArray *)[self entities] removeObject: entity];
-  else
-    {
-      id e = [NSMutableArray arrayWithArray: [self entities]];
-
-      [e removeObject: entity];
-      ASSIGNCOPY(_entities, e);
-    }
+  [(NSMutableArray *)[self entities] removeObject: entity];
 }
 
 - (void) removeEntityAndReferences: (EOEntity *)entity
@@ -1515,12 +1496,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
                  [storedProcedure name]];
   NSAssert(_storedProcedures, @"Uninitialised _storedProcedures!");
   [self willChange];
-  if ([self createsMutableObjects])
-    [(NSMutableArray *)_storedProcedures addObject: storedProcedure];
-  else
-    {
-      _storedProcedures = RETAIN([AUTORELEASE(_storedProcedures) arrayByAddingObject:storedProcedure]);
-    }
+  [(NSMutableArray *)_storedProcedures addObject: storedProcedure];
 }
 
 - (void)removeStoredProcedure: (EOStoredProcedure *)storedProcedure
@@ -1528,16 +1504,7 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   NSAssert(_storedProcedures, @"Uninitialised _storedProcedures!");
 
   [self willChange];
-  if ([self createsMutableObjects])
-    [(NSMutableArray *)_storedProcedures removeObject: storedProcedure];
-  else
-    {
-      NSMutableArray *mCopy = AUTORELEASE([_storedProcedures mutableCopy]);
-      [mCopy removeObject: storedProcedure];
-      mCopy = AUTORELEASE([[NSArray alloc] initWithArray: mCopy
-					   copyItems: NO]);
-      ASSIGN(_storedProcedures, mCopy);
-    }
+  [(NSMutableArray *)_storedProcedures removeObject: storedProcedure];
 }
 
 - (void) setModelGroup: (EOModelGroup *)group
@@ -1743,33 +1710,6 @@ NSString *EOEntityLoadedNotification = @"EOEntityLoadedNotification";
   return returnPath;
 }
 
-- (void) setCreateMutableObjects: (BOOL)flag
-{
-  if (_flags.createsMutableObjects != flag)
-    {
-      NSArray *entityArray = [self entities];
-      _flags.createsMutableObjects = flag;
-      
-      /* Do not access _entities until cache is triggered */
-      if (_flags.createsMutableObjects)
-	{
-	  entityArray = [[NSMutableArray alloc] initWithArray: entityArray
-						copyItems:NO];
-	}
-      else
-	{
-	  entityArray = [[NSArray alloc] initWithArray: entityArray
-					 copyItems:NO];
-	}
-      ASSIGN(_entities, entityArray);
-    }
-}
-
-- (BOOL) createsMutableObjects
-{
-  return _flags.createsMutableObjects;
-}
-
 - (EOEntity *) _verifyBuiltEntityObject: (id)entity
 				  named: (NSString*)name
 {
