@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: June 2000
 
-   $Revision: 24302 $
-   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
+   $Revision: 25994 $
+   $Date: 2008-01-22 14:57:07 +0100 (Die, 22. Jän 2008) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,6 +26,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
+
    If not, write to the Free Software Foundation,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    </license>
@@ -33,14 +34,15 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOModelGroup.m 24302 2007-01-01 11:52:38Z ayers $")
+RCS_ID("$Id: EOModelGroup.m 25994 2008-01-22 13:57:07Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSBundle.h>
-#include <Foundation/NSNotification.h>
-#include <Foundation/NSEnumerator.h>
-#include <Foundation/NSPathUtilities.h>
 #include <Foundation/NSDebug.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSNotification.h>
+#include <Foundation/NSPathUtilities.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -424,7 +426,7 @@ of the mainBundle, and all bundles and frameworks loaded into the app.
 
 @implementation EOObjectStoreCoordinator (EOModelGroup)
 
-- (id)modelGroup
+- (EOModelGroup *)modelGroup
 {
   //Seems OK
   EOModelGroup *modelGroup;
