@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -76,7 +76,7 @@ typedef enum {
     unsigned int isMandatory:1;
     unsigned int ownsDestination:1;
     unsigned int propagatesPrimaryKey:1;
-    unsigned int createsMutableObjects:1;
+    unsigned int unused:1;
     unsigned int isBidirectional:1;
     unsigned int extraRefCount:23;
   } _flags;
@@ -185,20 +185,6 @@ typedef enum {
 @end
 
 
-@interface EORelationship (EORelationshipPrivate)
-
-/*+ (EORelationship *)relationshipFromPropertyList: (id)propertyList
-	model: (EOModel *)model;
-- (void)replaceStringsWithObjects;
-- (void)initFlattenedRelationship;
-
-- (id)propertyList;*/
-
-- (void)setCreateMutableObjects: (BOOL)flag;
-- (BOOL)createsMutableObjects;
-- (void)setInverseRelationship: (EORelationship *)relationship;
-@end /* EORelationship (EORelationshipPrivate) */
-
 @interface EORelationship (EORelationshipXX)
 
 - (NSArray *)_intermediateAttributes;
