@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 25102 $
-   $Date: 2007-05-01 14:01:43 +0200 (Die, 01 Mai 2007) $
+   $Revision: 27916 $
+   $Date: 2009-02-18 15:47:26 +0100 (Mit, 18. Feb 2009) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,11 +36,10 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
+RCS_ID("$Id: EORelationship.m 27916 2009-02-18 14:47:26Z ratmice $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSException.h>
 #include <Foundation/NSDebug.h>
 #else
@@ -70,6 +69,10 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
 #include "EOAttributePriv.h"
 #include "EOEntityPriv.h"
 
+@interface EORelationship (EORelationshipPrivate)
+- (void)_setInverseRelationship: (EORelationship *)relationship;
+@end
+
 
 @implementation EORelationship
 
@@ -96,12 +99,14 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
 //OK
   if ((self = [super init]))
     {
-/*      _sourceNames = [NSMutableDictionary new];
+      /*
+      _sourceNames = [NSMutableDictionary new];
       _destinationNames = [NSMutableDictionary new];
       _userInfo = [NSDictionary new];
       _sourceToDestinationKeyMap = [NSDictionary new];
+      */
       _joins = [NSMutableArray new];
-*/
+
     }
 
   return self;
@@ -109,6 +114,8 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
 
 - (void)dealloc
 {
+  [self _flushCache];
+
   DESTROY(_name);
   DESTROY(_qualifier);
   DESTROY(_sourceNames);
@@ -116,9 +123,15 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
   DESTROY(_userInfo);
   DESTROY(_internalInfo);
   DESTROY(_docComment);
+  DESTROY(_joins);
   DESTROY(_sourceToDestinationKeyMap);
   DESTROY(_sourceRowToForeignKeyMapping);
 
+  DESTROY(_definitionArray);
+
+  _entity = nil;
+  _destination = nil;
+  
   [super dealloc];
 }
 
@@ -145,9 +158,9 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
       model = [owner model];
       relationshipName = [propertyList objectForKey: @"name"];
 
-      [self setName: relationshipName]; 
+      /* so setName: can validate against the owner */
       [self setEntity: owner];
-      [self setCreateMutableObjects: YES];
+      [self setName: relationshipName]; 
 
       destinationEntityName = [propertyList objectForKey: @"destination"];
 
@@ -155,8 +168,6 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
         {
           destinationEntity = [model entityNamed: destinationEntityName];
 
-	  GDL2DestinationEntitiesRemoveRelationship(_destination, self);
-	  GDL2DestinationEntitiesAddRelationship(destinationEntity, self);
           _destination = destinationEntity;
         }
 
@@ -375,8 +386,6 @@ RCS_ID("$Id: EORelationship.m 25102 2007-05-01 12:01:43Z ayers $")
     };
   */
 
-  [self setCreateMutableObjects: NO]; //?? tc say yes, mirko no
-
   EOFLOGObjectFnStop();
 }
 
@@ -552,6 +561,11 @@ destination entity of the last relationship in definition. **/
           NSAssert3(destinationEntity, @"No destinationEntity in last relationship: %@ of relationship %@ in entity %@",
                     lastRelationship, self, [_entity name]);
         }
+      else
+        {
+	  [self _joinsChanged];
+	  destinationEntity = _destination;
+	}
     }
   else if ([destinationEntity isKindOfClass: [NSString class]] == YES)
     destinationEntity = [[_entity model] 
@@ -676,8 +690,17 @@ to know what to-many mean :-)  **/
   return joinSemanticString;
 }
 
+/**
+ * Returns the array of relationships composing this flattend relationship.
+ * Returns nil of the reciever isn't flattend.
+ */
 - (NSArray *)componentRelationships
 {
+  /* FIXME:TODO: Have this method deterimne the components dynamically
+   without caching them in the ivar.  Possibly add some tracing code to
+   see if caching the values can actually improve performance.
+   (Unlikely that it's worth the trouble this may cause for entity
+   edititng). */
   if (!_componentRelationships)
     {
       return _definitionArray; //OK ??????
@@ -1034,7 +1057,7 @@ relationships. Nil if none" **/
 		    addObject: inverseRelationship]; //not very clean !!!
   EOFLOGObjectLevel(@"EORelationship", @"set inverse rel");
 
-  [inverseRelationship setInverseRelationship: self];
+  [inverseRelationship _setInverseRelationship: self];
 
   EOFLOGObjectFnStop();
 
@@ -1047,14 +1070,13 @@ relationships. Nil if none" **/
   EORelationship *inverseRelationship;
   NSString *name;
   NSArray *joins = nil;
-  int i, count;
+  unsigned int i, count;
 
   EOFLOGObjectFnStart();
 
   NSAssert(![self isFlattened], @"Flatten Relationship");
 
   inverseRelationship = [[EORelationship new] autorelease];
-  [inverseRelationship setEntity: _destination];
 
   name = [NSString stringWithFormat: @"_eofInv_%@_%@",
 		   [_entity name],
@@ -1085,8 +1107,10 @@ relationships. Nil if none" **/
 
   EOFLOGObjectLevel(@"EORelationship", @"set inverse rel");
 
-  [inverseRelationship setInverseRelationship: self];
+  [inverseRelationship _setInverseRelationship: self];
 
+  /* call this last to avoid calls to [_destination _setIsEdited] */
+  [inverseRelationship setEntity: _destination];
   EOFLOGObjectFnStop();
 
   return inverseRelationship;
@@ -1178,7 +1202,7 @@ relationships. Nil if none" **/
 					 *p]
                         userInfo: nil];
       
-      if ([[self entity] anyAttributeNamed: name])
+      if ([[self entity] _hasAttributeNamed: name])
         exc++;
       else if ([[self entity] anyRelationshipNamed: name])
         exc++;
@@ -1231,8 +1255,12 @@ relationships. Nil if none" **/
                  NSStringFromClass([self class]),
                  self];
 
-  [self willChange];
-  _flags.isToMany = flag;
+  if (_flags.isToMany != flag)
+    {
+      [self willChange];
+      [_entity _setIsEdited];
+      _flags.isToMany = flag;
+    }
 }
 
 - (void)setName: (NSString *)name
@@ -1242,7 +1270,7 @@ relationships. Nil if none" **/
   [self willChange];
   [_entity _setIsEdited];
 
-  ASSIGN(_name, name);
+  ASSIGNCOPY(_name, name);
 }
 
 - (void)setDefinition: (NSString *)definition
@@ -1267,7 +1295,6 @@ relationships. Nil if none" **/
       EOFLOGObjectLevelArgs(@"EORelationship", @"_definitionArray=%@", _definitionArray);
       EOFLOGObjectLevelArgs(@"EORelationship", @"[self definition]=%@", [self definition]);
 
-      GDL2DestinationEntitiesRemoveRelationship(_destination, self);
       _destination = nil;
 
       {        
@@ -1303,6 +1330,15 @@ relationships. Nil if none" **/
   EOFLOGObjectFnStop();
 }
 
+/**
+ * <p>Sets the entity of the reciever.</p>
+ * <p>If the receiver already has an entity assigned to it the old relationship
+ * will will be removed first.</p>
+ * <p>This method is used by [EOEntity-addRelationship:] and
+ * [EOEntity-removeRelationship:] which should be used for general relationship
+ * manipulations.  This method should only be useful
+ * when creating flattend relationships programmatically.</p>
+ */
 - (void)setEntity: (EOEntity *)entity
 {
   //OK
@@ -1310,13 +1346,26 @@ relationships. Nil if none" **/
     {
       [self _flushCache];
       [self willChange];
-      /* FIXME docs say we should... but currently -removeRelationship 
-       * calls us, so it would cause an infinite loop */
-      // [_entity removeRelationship:self];
-      [_entity _setIsEdited];
-      [entity _setIsEdited];
+
+      if (_entity)
+	{
+	  NSString *relationshipName;
+	  EORelationship *relationship;
+
+	  /* Check if we are still in the entities arrays to
+	     avoid recursive loop when removeRelationship:
+	     calls this method.  */
+	  relationshipName = [self name];
+	  relationship = [_entity relationshipNamed: relationshipName];
+          if (self == relationship)
+	    {
+	      [_entity removeRelationship: self];
+	    }
+	}
       _entity = entity;
     }
+  /* This method is used by EOEntity's remove/addRelatinship: and is not
+     responsible for calling _setIsEdited on the entity.  */
 }
 
 - (void)setUserInfo: (NSDictionary *)dictionary
@@ -1341,7 +1390,7 @@ relationships. Nil if none" **/
 {
   //OK
   [self willChange];
-  ASSIGN(_docComment, docComment);
+  ASSIGNCOPY(_docComment, docComment);
   /* Ayers: Not sure what justifies this. */
   [_entity _setIsEdited];
 }
@@ -1487,38 +1536,14 @@ relationships. Nil if none" **/
                 EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 				      _joins, [_joins class]);
 
-                if ([self createsMutableObjects])
-                  {
-                    if (!_joins)
-                      _joins = [NSMutableArray new];
+                if (!_joins)
+                  _joins = [NSMutableArray new];
 
-                    [(NSMutableArray *)_joins addObject: join];      
+                [(NSMutableArray *)_joins addObject: join];      
 
-                    EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
+                EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 					  _joins, [_joins class]);
 
-                  }
-                else
-                  {
-                    if (_joins)
-                      _joins = RETAIN([[_joins autorelease]
-				  arrayByAddingObject: join]);
-                    else
-                      _joins = RETAIN([NSArray arrayWithObject: join]);
-
-                    EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
-					  _joins, [_joins class]);
-
-                    /*NO: will be recomputed      _sourceAttributes = [[[_sourceAttributes autorelease]
-                      arrayByAddingObject:[join sourceAttribute]]
-                      retain];
-                      _destinationAttributes = [[[_destinationAttributes autorelease]
-                      arrayByAddingObject:
-                      [join destinationAttribute]]
-                      retain];
-                    */
-                  }
-
                 EOFLOGObjectLevel(@"EORelationship", @"added");
 
                 [self _joinsChanged];
@@ -1546,9 +1571,7 @@ relationships. Nil if none" **/
   else
     {
       [self willChange];
-      if ([self createsMutableObjects])
-        {
-          [(NSMutableArray *)_joins removeObject: join];
+      [(NSMutableArray *)_joins removeObject: join];
 
           /*NO: will be recomputed      [(NSMutableArray *)_sourceAttributes
             removeObject:[join sourceAttribute]];
@@ -1556,34 +1579,8 @@ relationships. Nil if none" **/
             removeObject:[join destinationAttribute]];
           */
 
-          EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
+      EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
 		       _joins, [_joins class]);
-        }
-      else
-        {
-	  NSMutableArray	*ma = [_joins mutableCopy];
-	  NSArray		*a = _joins;
-	  
-	  [ma removeObject: join];
-	  _joins = ma;
-          [a release];
-
-          EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
-				_joins, [_joins class]);
-
-          /*NO: will be recomputed
-            _sourceAttributes = [[_sourceAttributes autorelease] mutableCopy];
-            [(NSMutableArray *)_sourceAttributes
-            removeObject:[join sourceAttribute]];
-            _sourceAttributes = [[_sourceAttributes autorelease] copy];
-      
-            _destinationAttributes = [[_destinationAttributes autorelease]
-            mutableCopy];
-            [(NSMutableArray *)_destinationAttributes
-            removeObject:[join destinationAttribute]];
-            _destinationAttributes = [[_destinationAttributes autorelease] copy];
-          */
-        }
 
       [self _joinsChanged];
       /* Ayers: Not sure what justifies this. */
@@ -1717,52 +1714,16 @@ becomes "name", and "FIRST_NAME" becomes "firstName".*/
 
 @implementation EORelationship (EORelationshipPrivate)
 
-- (void)setCreateMutableObjects: (BOOL)flag
+/*
+  This method is private to GDL2 to allow the inverse relationship
+  to be set from the original relationship.  It exists to avoid the
+  ASSIGN(inverseRelationship->_inverseRelationship, self);
+  and to insure that associations will be updated if we ever display
+  inverse relationships in DBModeler.
+*/
+- (void)_setInverseRelationship: (EORelationship*)relationship
 {
-  if (_flags.createsMutableObjects != flag)
-    {
-      _flags.createsMutableObjects = flag;
-
-      if (_flags.createsMutableObjects)
-        {
-          _joins = [[_joins autorelease] mutableCopy];
-
-          EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
-		       _joins, [_joins class]);
-
-          DESTROY(_sourceAttributes);
-          DESTROY(_destinationAttributes);
-          /*Will be recomputed later      _sourceAttributes = [[_sourceAttributes autorelease] mutableCopy];
-            _destinationAttributes = [[_destinationAttributes autorelease]
-            mutableCopy];
-          */
-        }
-      else
-        {
-          _joins = [[NSArray alloc] initWithArray:[_joins autorelease] copyItems:NO];
-
-          EOFLOGObjectLevelArgs(@"EORelationship", @"XXjoins %p class%@",
-		       _joins, [_joins class]);
-
-          DESTROY(_sourceAttributes);
-          DESTROY(_destinationAttributes);
-
-          /*Will be recomputed later      _sourceAttributes = [[_sourceAttributes autorelease] copy];
-            _destinationAttributes = [[_destinationAttributes autorelease] copy];
-          */
-        }
-    }
-}
-
-- (BOOL)createsMutableObjects
-{
-  return _flags.createsMutableObjects;
-}
-
-/* TODO this method should probably be private. */
-- (void)setInverseRelationship: (EORelationship*)relationship
-{
-  [self willChange]; // TODO: verify
+  [self willChange];
   ASSIGN(_inverseRelationship,relationship);
 }
 
@@ -2215,6 +2176,9 @@ dst entity primaryKeyAttributeNames
   DESTROY(_destinationAttributes);
   DESTROY(_inverseRelationship);
   DESTROY(_hiddenInverseRelationship);
+  DESTROY(_componentRelationships);
+  _destination = nil;
+
 }
 
 - (EOExpressionArray*) _definitionArray
@@ -2355,40 +2319,26 @@ dst entity primaryKeyAttributeNames
 
 - (void) _joinsChanged
 {
-  //TODO VERIFY
-  int count;
+  //VERIFIED DA 
+  int count = [_joins count];
 
   EOFLOGObjectFnStart();
 
-  count = [_joins count];
 
   EOFLOGObjectLevelArgs(@"EORelationship", @"_joinsChanged:%@\nin %@", _joins, self);
 
   if (count > 0)
     {
-      int i;
+      EOJoin *join = [_joins objectAtIndex: 0];
+      EOAttribute *destinationAttribute = [join destinationAttribute];
+      EOEntity *destinationEntity = [destinationAttribute entity];
 
-      for (i = 0; i < count; i++)
-        {
-          EOJoin *join = [_joins objectAtIndex: i];
-          EOAttribute *destinationAttribute = [join destinationAttribute];
-          EOEntity *destinationEntity = [destinationAttribute entity];
-
-	  GDL2DestinationEntitiesRemoveRelationship(_destination, self);
-	  GDL2DestinationEntitiesAddRelationship(destinationEntity, self);
-          _destination = destinationEntity;
-        }
+      _destination = destinationEntity;
     }
   else
     {
       _destination = nil;
     }
-//_joins count
-  //[self notImplemented:_cmd]; // TODO-NOW
-/*
-join destinationAttribute
-attr entity
-*/
 
   EOFLOGObjectFnStop();
 }
