@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 24302 $
-   $Date: 2007-01-01 12:52:38 +0100 (Mon, 01 Jän 2007) $
+   $Revision: 27922 $
+   $Date: 2009-02-19 12:15:22 +0100 (Don, 19. Feb 2009) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,18 +36,19 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOSQLExpression.m 24302 2007-01-01 11:52:38Z ayers $")
+RCS_ID("$Id: EOSQLExpression.m 27922 2009-02-19 11:15:22Z ayers $")
 
 #include <string.h>
 
 #ifdef GNUSTEP
-#include <Foundation/NSString.h>
-#include <Foundation/NSSet.h>
-#include <Foundation/NSUtilities.h>
-#include <Foundation/NSNotification.h>
-#include <Foundation/NSException.h>
-#include <Foundation/NSUserDefaults.h>
 #include <Foundation/NSDebug.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
+#include <Foundation/NSNotification.h>
+#include <Foundation/NSSet.h>
+#include <Foundation/NSString.h>
+#include <Foundation/NSUserDefaults.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -703,7 +704,17 @@ NSString *EOBindVariableColumnKey = @"EOBindVariableColumnKey";
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"fetchQualifier=%@",
 			fetchQualifier);
 
-  restrictingQualifier = [_entity restrictingQualifier]; //OK //nil //TODO use it !! 
+  restrictingQualifier = [_entity restrictingQualifier]; 
+
+  if (fetchQualifier && restrictingQualifier)
+    {
+      fetchQualifier = [[EOAndQualifier alloc] initWithQualifiers:fetchQualifier, restrictingQualifier, nil];
+      AUTORELEASE(fetchQualifier);
+    }
+  else
+    {
+      fetchQualifier = fetchQualifier ? fetchQualifier : restrictingQualifier;
+    }
 
   //Build Where Clause
   whereClauseString = [(id<EOQualifierSQLGeneration>)fetchQualifier sqlStringForSQLExpression: self];
@@ -2233,7 +2244,7 @@ else if([attribute isDerived] == YES)
 }
 
 - (NSMutableDictionary *)bindVariableDictionaryForAttribute: (EOAttribute *)attribute
-                                                      value: value
+                                                      value: (id)value
 {
   [self subclassResponsibility: _cmd];
   return nil;
