@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,8 +38,10 @@ RCS_ID("$Id: EOSchemaGeneration.m 23653 2006-09-28 15:25:30Z ratmice $")
 #include <string.h>
 
 #ifdef GNUSTEP
-#include <Foundation/NSString.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSDictionary.h>
 #include <Foundation/NSNotification.h>
+#include <Foundation/NSString.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
