@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 23874 $
-   $Date: 2006-10-15 14:23:42 +0200 (Son, 15 Okt 2006) $
+   $Revision: 26594 $
+   $Date: 2008-06-06 01:14:14 +0200 (Fre, 06. Jun 2008) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,13 +33,14 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOStoredProcedure.m 23874 2006-10-15 12:23:42Z ratmice $")
+RCS_ID("$Id: EOStoredProcedure.m 26594 2008-06-05 23:14:14Z ratmice $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSException.h>
-#include <Foundation/NSEnumerator.h>
-#include <Foundation/NSDebug.h>
 #include <Foundation/NSArray.h>
+#include <Foundation/NSDebug.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -91,7 +92,16 @@ RCS_ID("$Id: EOStoredProcedure.m 23874 2006-10-15 12:23:42Z ratmice $")
   if (!_userInfo)
     [self setUserInfo:[propertyList objectForKey:@"userInfo"]];
 
-  array = [propertyList objectForKey:@"attributes"];
+  array = [propertyList objectForKey:@"arguments"];
+  if (!array)
+    {
+      array = [propertyList objectForKey:@"attributes"];
+      if (array)
+        {
+	  NSLog(@"warning found 'attributes' key in property list you should"
+		@"fix your model files to use the 'arguments' key!!");
+	}
+    }
   if ([array count])
     {
       _arguments = [[NSMutableArray alloc] initWithCapacity: [array count]];
@@ -155,7 +165,7 @@ RCS_ID("$Id: EOStoredProcedure.m 23874 2006-10-15 12:23:42Z ratmice $")
 	  [attributesPList addObject: attributePList];
 	}
 
-      [propertyList setObject: attributesPList forKey: @"attributes"];
+      [propertyList setObject: attributesPList forKey: @"arguments"];
     }
 }
 
@@ -197,13 +207,13 @@ RCS_ID("$Id: EOStoredProcedure.m 23874 2006-10-15 12:23:42Z ratmice $")
 - (void)setName: (NSString *)name
 {
   [self willChange];
-  ASSIGN(_name, name);
+  ASSIGNCOPY(_name, name);
 }
 
 - (void)setExternalName: (NSString *)name
 {
   [self willChange];
-  ASSIGN(_externalName, name);
+  ASSIGNCOPY(_externalName, name);
 }
 
 - (void)setArguments: (NSArray *)arguments
