@@ -10,7 +10,7 @@
 
    The GNUstep Database Library is free software; you can redistribute it 
    and/or modify it under the terms of the GNU Lesser General Public License 
-   as published by the Free Software Foundation; either version 2, 
+   as published by the Free Software Foundation; either version 3, 
    or (at your option) any later version.
 
    The GNUstep Database Library is distributed in the hope that it will be 
@@ -24,20 +24,23 @@
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. 
 */
 
-#include <Foundation/Foundation.h>
-#include <AppKit/AppKit.h>
 #include <EOAccess/EOAccess.h>
 
 #ifndef GNUSTEP
+#import <Foundation/Foundation.h>
+#import <AppKit/AppKit.h>
 #include <GNUstepBase/GNUstep.h>
 #include <GNUstepBase/GSCategories.h>
+#else
+#include <Foundation/Foundation.h>
+#include <AppKit/AppKit.h>
 #endif
 
 #include "PostgreSQLLoginPanel.h"
 
 static BOOL insideModalLoop;
 
-static NSString *windowTitle = @"PostgreSQLql login";
+static NSString *windowTitle = @"PostgreSQL login";
 static NSString *newDatabaseTitle = @"New";
 static NSString *userNameTitle = @"Username: ";
 static NSString *passwordTitle = @"Password: ";
@@ -332,7 +335,7 @@ vfmaxf (int n, float aFloat, ...)
       
       _win = [[NSWindow alloc] initWithContentRect: tempRect 
 			       styleMask: NSTitledWindowMask
-			       backing: NSBackingStoreRetained
+			       backing: NSBackingStoreBuffered
 			       defer: YES];
       [_win setTitle: windowTitle];
       [_win setDelegate:self];
