@@ -12,8 +12,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 25060 $
-   $Date: 2007-04-16 09:24:18 +0200 (Mon, 16 Apr 2007) $
+   $Revision: 25994 $
+   $Date: 2008-01-22 14:57:07 +0100 (Die, 22. Jän 2008) $
 
    <abstract></abstract>
 
@@ -23,7 +23,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -39,7 +39,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: PostgreSQLChannel.m 25060 2007-04-16 07:24:18Z ayers $")
+RCS_ID("$Id: PostgreSQLChannel.m 25994 2008-01-22 13:57:07Z ayers $")
 
 
 #ifdef GNUSTEP
@@ -54,7 +54,6 @@ RCS_ID("$Id: PostgreSQLChannel.m 25060 2007-04-16 07:24:18Z ayers $")
 #include <Foundation/NSString.h>
 #include <Foundation/NSSet.h>
 #include <Foundation/NSTimeZone.h>
-#include <Foundation/NSUtilities.h>
 #else
 #include <Foundation/Foundation.h>
 #include <GNUstepBase/GSCategories.h>
@@ -84,7 +83,7 @@ RCS_ID("$Id: PostgreSQLChannel.m 25060 2007-04-16 07:24:18Z ayers $")
 
 @interface EOAttribute (private)
 - (Class)_valueClass;
-- (char)_valueTypeChar;
+- (char)_valueTypeCharacter;
 @end
 
 static BOOL attrRespondsToValueClass = NO;
@@ -263,9 +262,16 @@ newValueForNumberTypeLengthAttribute(const void *bytes,
         }
       else
         {
-          char valueTypeChar = attrRespondsToValueTypeChar
-	    ? [attribute _valueTypeChar]
-	    : [[attribute valueType] cString][0];
+          char valueTypeChar = '\0';
+	  if (attrRespondsToValueTypeChar)
+	    {
+	      valueTypeChar = [attribute _valueTypeCharacter];
+	    }
+	  else
+	    {
+	      NSString *vt = [attribute valueType];
+	      if (vt) valueTypeChar = [[attribute valueType] UTF8String][0];
+	    }
           switch(valueTypeChar)
             {
             case 'i':
@@ -475,7 +481,7 @@ newValueForBytesLengthAttribute (const void *bytes,
       attrRespondsToValueClass
 	= [EOAttribute instancesRespondToSelector: @selector(_valueClass)];
       attrRespondsToValueTypeChar
-	= [EOAttribute instancesRespondToSelector: @selector(_valueTypeChar)];
+	= [EOAttribute instancesRespondToSelector: @selector(_valueTypeCharacter)];
 
       initialized = YES;
     };
