@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 24298 $
-   $Date: 2006-12-31 02:32:05 +0100 (Son, 31 Dez 2006) $
+   $Revision: 26427 $
+   $Date: 2008-04-03 08:24:26 +0200 (Don, 03. Apr 2008) $
 
    <abstract></abstract>
 
@@ -18,7 +18,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,19 +34,20 @@
 
 #include "config.h"
 
-RCS_ID("$Id: PostgreSQLExpression.m 24298 2006-12-31 01:32:05Z ayers $")
+RCS_ID("$Id: PostgreSQLExpression.m 26427 2008-04-03 06:24:26Z ratmice $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSUtilities.h>
-#include <Foundation/NSException.h>
+#include <Foundation/NSData.h>
 #include <Foundation/NSDebug.h>
+#include <Foundation/NSDecimal.h>
+#include <Foundation/NSDecimalNumber.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
 
-#include <Foundation/NSDecimal.h>
-#include <Foundation/NSDecimalNumber.h>
-
 #ifndef GNUSTEP
 #include <GNUstepBase/GNUstep.h>
 #include <GNUstepBase/GSCategories.h>
@@ -96,9 +97,6 @@ RCS_ID("$Id: PostgreSQLExpression.m 24298 2006-12-31 01:32:05Z ayers $")
 {
   NSString *formatted = nil;
   NSString        *externalType;
-  NSMutableString *string;
-  const char      *tempString;
-  int              i, dif;
 
   EOFLOGObjectFnStart();
 
@@ -331,46 +329,39 @@ RCS_ID("$Id: PostgreSQLExpression.m 24298 2006-12-31 01:32:05Z ayers $")
     }
   else // String...
     {
-      int length = 0;
+      NSMutableString *string = [NSMutableString stringWithFormat:@"%@", value];
+      unsigned i, dif;
+      unsigned length = [string length];
 
-      EOFLOGObjectLevelArgs(@"EOSQLExpression",
-			    @"other case - value=%@ class=%@",
-			    value, [value class]);      
-
-      string = [NSMutableString stringWithFormat: @"%@", value];
-
-      EOFLOGObjectLevelArgs(@"EOSQLExpression", @"string %p='%@'",
-			    string, string);
-
-      length=[string cStringLength];
-      tempString = [string cString];
-      EOFLOGObjectLevelArgs(@"EOSQLExpression", @"string '%@' tempString=%s",
-			    string, tempString);
-
-      for (i = 0, dif = 0; i < length; i++)
+      if (length > 0)
         {
-          switch (tempString[i])
+          unichar tempString[length];
+
+	  [string getCharacters:tempString];
+
+	  for (i = 0, dif = 0; i < length; i++)
             {
-            case '\\':
-            case '\'':
-              [string insertString: @"\\" atIndex: dif + i];
-              dif++;
-              break;
-            case '_':
-              [string insertString: @"\\" atIndex: dif + i];
-              dif++;
-              break;
-            default:
-              break;
+              switch (tempString[i])
+                {
+		case '\'':
+		  [string insertString: @"'" atIndex: dif + i];
+                  dif++;
+                  break;
+                case '\\':
+                  [string insertString: @"\\" atIndex: dif + i];
+                  dif++;
+                  break;
+                case '_':
+                  [string insertString: @"\\" atIndex: dif + i];
+                  dif++;
+                  break;
+                default:
+                  break;
+                }
             }
         }
-      EOFLOGObjectLevelArgs(@"EOSQLExpression", @"string '%@' tempString=%s",
-			    string, tempString);
 
       formatted = [NSString stringWithFormat: @"'%@'", string];      
-
-      EOFLOGObjectLevelArgs(@"EOSQLExpression", @"formatted %p=%@",
-			    formatted, formatted);
     }
 
   EOFLOGObjectLevelArgs(@"EOSQLExpression", @"formatted=%@", formatted);
