@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: January 2002
 
-   $Revision: 23510 $
-   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
+   $Revision: 25994 $
+   $Date: 2008-01-22 14:57:07 +0100 (Die, 22. Jän 2008) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,13 +36,13 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOAndQualifier.m 23510 2006-09-14 16:06:21Z ayers $")
+RCS_ID("$Id: EOAndQualifier.m 25994 2008-01-22 13:57:07Z ayers $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSDictionary.h>
-#include <Foundation/NSSet.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSDebug.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSSet.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
