@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,9 +38,10 @@
 #include <EOControl/EODefines.h>
 
 @class NSDictionary;
-@class NSFormatter;
 @class EOEditingContext;
+@class NSFormatter;
 @class EOGlobalID;
+@class NSMutableDictionary;
 @class EORelationship;
 
 typedef enum
@@ -141,6 +142,7 @@ fromFetchInEditingContext: (EOEditingContext *)editingContext;
 - (NSString *)userPresentableDescription;
 
 - (NSException *)validateValue: (id *)valueP forKey: (NSString *)key;
+- (id)validateTakeValue:(id)value forKeyPath:(NSString *)path;
 
 - (NSException *)validateForSave;
 
