@@ -10,8 +10,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: November 2001
 
-   $Revision: 24297 $
-   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
+   $Revision: 26748 $
+   $Date: 2008-07-06 12:52:27 +0200 (Son, 06. Jul 2008) $
 
    <abstract></abstract>
 
@@ -21,7 +21,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -37,7 +37,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOClassDescription.m 24297 2006-12-30 17:41:02Z ayers $")
+RCS_ID("$Id: EOClassDescription.m 26748 2008-07-06 10:52:27Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSString.h>
@@ -164,15 +164,10 @@ static NSRecursiveLock *local_lock = nil;
 {
   EOClassDescription *classDescription;
 
-  EOFLOGObjectFnStart();
-
-  NSDebugMLLog(@"gsdb", @"aClass=%@", aClass);
   NSAssert(aClass, @"No class");
-  NSDebugMLLog(@"gsdb", @"class name=%s", GSNameFromClass(aClass));
 
   classDescription = NSMapGet(classDescriptionForClass, aClass);  
 
-  NSDebugMLLog(@"gsdb", @"classDescription=%@", classDescription);
   if (!classDescription)
     {
       [[NSNotificationCenter defaultCenter]
@@ -180,18 +175,16 @@ static NSRecursiveLock *local_lock = nil;
 	object: aClass];
 
       classDescription = NSMapGet(classDescriptionForClass, aClass);
-      NSDebugMLLog(@"gsdb", @"classDescription=%@", classDescription);
 
       if (!classDescription)
         {
-          NSLog(@"Warning: No class description for class named: %s",
-		GSNameFromClass(aClass));
+          NSLog(@"Warning: No class description for class named: %@",
+		NSStringFromClass(aClass));
+	  NSMapInsert(classDescriptionForClass, aClass, GDL2_EONull);
         }
     }
 
-  EOFLOGObjectFnStop();
-
-  return classDescription;
+  return classDescription == (id)GDL2_EONull ? nil : classDescription;
 }
 
 + (EOClassDescription *)classDescriptionForEntityName: (NSString *)entityName
@@ -712,6 +705,7 @@ fromInsertionInEditingContext: (EOEditingContext *)editingContext
   return nil;
 }
 
+
 @end
 
 @implementation EOClassDescription (Deprecated)
@@ -962,7 +956,7 @@ fromInsertionInEditingContext: (EOEditingContext *)editingContext
         {
 	  SEL validateSelector;
 	  unsigned length = [key length];
-	  unsigned char buf[length + 10];
+	  char buf[length + 10];
 
 	  strcpy(buf, "validate");
 	  [key getCString: &buf[8]];
@@ -984,6 +978,47 @@ fromInsertionInEditingContext: (EOEditingContext *)editingContext
   return exception;
 }
 
+/**
+ * This method is called to validate and potentially coerce
+ * VALUE for the receivers key path.  This method also assigns
+ * the value if it is different from the current value.
+ * This method will raise an EOValidationException
+ * if validateValue:forKey: returns an exception.
+ * This method returns new value.
+ **/
+- (id)validateTakeValue:(id)value forKeyPath:(NSString *)path
+{
+  id nval = value;
+  id oval;
+  NSRange	r = [path rangeOfString: @"."];
+  
+  if (r.length == 0)
+    {
+      NSException *e = [self validateValue:&nval forKey:path];
+
+      if (e)
+	{
+	  [e raise];
+	}
+
+      oval = [self valueForKey:path];
+      if (nval != oval && 
+	  ((nval == nil || oval == nil) || [nval isEqual: oval] == NO))
+	{
+	  [self takeValue:nval forKey: path];
+	}
+    }
+  else
+    {
+      NSString	*key = [path substringToIndex: r.location];
+      NSString	*kpath = [path substringFromIndex: NSMaxRange(r)];
+
+      nval = [[self valueForKey: key] validateTakeValue: nval forKeyPath: kpath];
+    }
+  return nval;
+}
+
+
 - (NSException *)validateForSave
 {
   NSMutableArray *expArray = nil;
