@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,14 +27,27 @@
 #ifndef __EOControl_EODefines_h__
 #define __EOControl_EODefines_h__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifdef GNUSTEP_WITH_DLL
 
-#if BUILD_libgnustep_db2control_DLL
+#if BUILD_libEOControl_DLL
+
+# if defined(__MINGW32__)
+  /* On Mingw, the compiler will export all symbols automatically, so
+   * __declspec(dllexport) is not needed.
+   */
+#  define GDL2CONTROL_EXPORT  extern
+#  define GDL2CONTROL_DECLARE
+# else
 #  define GDL2CONTROL_EXPORT  __declspec(dllexport)
-#  define GDL2CONTROL_DECLARE __declspec(dllexport) 
+#  define GDL2CONTROL_DECLARE __declspec(dllexport)
+# endif
 #else
 #  define GDL2CONTROL_EXPORT  extern __declspec(dllimport)
-#  define GDL2CONTROL_DECLARE __declspec(dllimport) 
+#  define GDL2CONTROL_DECLARE __declspec(dllimport)
 #endif
 
 #else /* GNUSTEP_WITH[OUT]_DLL */
@@ -44,6 +57,9 @@
 
 #endif
 
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* __EOControl_EODefines_h__ */
 
