@@ -9,8 +9,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: June 2000
 
-   $Revision: 24307 $
-   $Date: 2007-01-03 06:43:12 +0100 (Mit, 03 Jän 2007) $
+   $Revision: 26237 $
+   $Date: 2008-03-07 12:09:35 +0100 (Fre, 07. Mär 2008) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,11 +36,10 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOFault.m 24307 2007-01-03 05:43:12Z ratmice $")
+RCS_ID("$Id: EOFault.m 26237 2008-03-07 11:09:35Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSObject.h>
-#include <Foundation/NSUtilities.h>
 #include <Foundation/NSAutoreleasePool.h>
 #include <Foundation/NSArray.h>
 #include <Foundation/NSDictionary.h>
@@ -83,6 +82,18 @@ static Class EOFaultClass = NULL;
   // without asking if it responds to it !
   if (EOFaultClass == NULL)
     {
+      GSMethod nsfwd = GSGetMethod([NSObject class],
+				    @selector(forward::),
+				    YES,NO);
+      if (nsfwd != NULL)
+        {
+          GSMethod eofwd = GSGetMethod(self,
+                                        @selector(forward::),
+                                        YES,NO);
+          eofwd->method_imp = nsfwd->method_imp;
+          GSFlushMethodCacheForClass(self);
+        }
+
       EOFaultClass = [EOFault class];
     }
 }
@@ -478,19 +489,17 @@ static Class EOFaultClass = NULL;
                NSStringFromSelector(selector)];
 }
 
-- (retval_t)forward: (SEL)selector 
+/**
+ * This method is replaced by the current implementation of NSObject (if any).
+ *
+ * It is assumed that this method will not be called if NSObject does not
+ * implement it.
+ */
+- (retval_t)forward: (SEL)selector
                    : (arglist_t)args
 {
-  retval_t ret;
-  NSInvocation *inv;
-
-  inv = [[[NSInvocation alloc] initWithArgframe: args
-			       selector: selector]
-	  autorelease];
-  [self forwardInvocation: inv];
-
-  ret = [inv returnFrame: args];
-
+  retval_t ret = 0;
+  NSAssert(NO,@"This should never be called (see +initialize).");
   return ret;
 }
 
