@@ -9,8 +9,8 @@
    Author: Manuel Guesdon <mguesdon@orange-concept.com>
    Date: October 2000
 
-   $Revision: 24297 $
-   $Date: 2006-12-30 18:41:02 +0100 (Sam, 30 Dez 2006) $
+   $Revision: 25545 $
+   $Date: 2007-10-31 06:32:46 +0100 (Mit, 31. Okt 2007) $
 
    <abstract></abstract>
 
@@ -20,7 +20,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -36,7 +36,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOGenericRecord.m 24297 2006-12-30 17:41:02Z ayers $")
+RCS_ID("$Id: EOGenericRecord.m 25545 2007-10-31 05:32:46Z ayers $")
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
@@ -246,7 +246,7 @@ static const char _c_id[2] = { _C_ID, 0 };
 	  if (size)
 	    *size = sizeof(id);
 	  if (offset)
-	    *offset = UINT_MAX; //Special Marker
+	    *offset = INT_MAX; //Special Marker
 
           ok = YES;
 
@@ -266,7 +266,7 @@ static const char _c_id[2] = { _C_ID, 0 };
 	     selector: (SEL)sel
 		 type: (const char*)type
 		 size: (unsigned)size
-	       offset: (unsigned)offset
+	       offset: (int)offset
 {
   id value = nil;
 
@@ -275,7 +275,7 @@ static const char _c_id[2] = { _C_ID, 0 };
 			@"Super InstanceVar named %@: sel=%@ type=%s size=%u offset=%u",
 			aKey,NSStringFromSelector(sel),type,size,offset);
 
-  if (offset == UINT_MAX)
+  if (offset == INT_MAX)
     {
       value = EOMKKD_objectForKeyWithImpPtr(dictionary,NULL,aKey);
 
@@ -300,14 +300,14 @@ static const char _c_id[2] = { _C_ID, 0 };
 	       selector: (SEL)sel
 		   type: (const char*)type
 		   size: (unsigned)size
-		 offset: (unsigned)offset
+		 offset: (int)offset
 {
   EOFLOGObjectFnStartCond(@"EOGenericRecordKVC");
   EOFLOGObjectLevelArgs(@"EOGenericRecordKVC",
 			@"Super InstanceVar named %@: offset=%u",
 			aKey, offset);
 
-  if (offset == UINT_MAX)
+  if (offset == INT_MAX)
     {
       if (anObject)
         EOMKKD_setObjectForKeyWithImpPtr(dictionary,NULL,anObject,aKey);
@@ -429,7 +429,7 @@ inline BOOL infoForInstanceVariableWithImpPtr(id object,GDL2IMP_BOOL* impPtr,
   SEL		sel = 0;
   const char	*type = NULL;
   unsigned	size = 0;
-  unsigned	off = 0;
+  int		off = 0;
   id value = nil;
   Class 	selfClass=[self class];
 
@@ -583,7 +583,7 @@ inline BOOL infoForInstanceVariableWithImpPtr(id object,GDL2IMP_BOOL* impPtr,
   SEL		sel = NULL;
   const char	*type = NULL;
   unsigned	size = 0;
-  unsigned	off = 0;
+  int		off = 0;
   Class 	selfClass=[self class];
 
   EOFLOGObjectFnStartCond(@"EOGenericRecordKVC");
@@ -767,7 +767,7 @@ inline BOOL infoForInstanceVariableWithImpPtr(id object,GDL2IMP_BOOL* impPtr,
   SEL		sel;
   const char	*type;
   unsigned	size;
-  unsigned	off=0;
+  int		off=0;
 
   EOFLOGObjectFnStartCond(@"EOGenericRecordKVC");
   EOFLOGObjectLevelArgs(@"EOGenericRecordKVC", @"anObject=%@", anObject);
@@ -897,7 +897,7 @@ inline BOOL infoForInstanceVariableWithImpPtr(id object,GDL2IMP_BOOL* impPtr,
   SEL		sel = 0;
   const char	*type = NULL;
   unsigned	size;
-  unsigned	off = 0;
+  int		off = 0;
   id value = nil;
 
   EOFLOGObjectFnStartCond(@"EOGenericRecordKVC");
