@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 23510 $
-   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
+   $Revision: 27724 $
+   $Date: 2009-01-29 23:34:41 +0100 (Don, 29. Jän 2009) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,14 +33,15 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOGlobalID.m 23510 2006-09-14 16:06:21Z ayers $")
+RCS_ID("$Id: EOGlobalID.m 27724 2009-01-29 22:34:41Z ratmice $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSCoder.h>
-#include <Foundation/NSString.h>
 #include <Foundation/NSArray.h>
-#include <Foundation/NSProcessInfo.h>
+#include <Foundation/NSCoder.h>
+#include <Foundation/NSData.h>
 #include <Foundation/NSHost.h>
+#include <Foundation/NSProcessInfo.h>
+#include <Foundation/NSString.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -53,6 +54,7 @@ RCS_ID("$Id: EOGlobalID.m 23510 2006-09-14 16:06:21Z ayers $")
 #include <EOControl/EODebug.h>
 
 #include <string.h>
+#include <limits.h>
 
 NSString *EOGlobalIDChangedNotification = @"EOGlobalIDChangedNotification";
 
@@ -95,7 +97,7 @@ NSString *EOGlobalIDChangedNotification = @"EOGlobalIDChangedNotification";
 
 @implementation EOTemporaryGlobalID
 
-static unsigned short sequence = (unsigned short)-1;
+static unsigned short sequence = USHRT_MAX;
 
 + (EOTemporaryGlobalID *)temporaryGlobalID
 {
@@ -113,7 +115,7 @@ static unsigned short sequence = (unsigned short)-1;
 + (void)assignGloballyUniqueBytes: (unsigned char *)buffer
 {
   static int pid = 0;
-  static unsigned char ipComp[4];
+  static union { unsigned int i; unsigned char c[4]; } ipComp = { .i = 0 };
   unsigned char *bPtr;
   unsigned short seq;
   unsigned int i;
@@ -132,10 +134,26 @@ static unsigned short sequence = (unsigned short)-1;
       ipString = [[NSHost currentHost] address];
       ipComps = [ipString componentsSeparatedByString: @"."];
 
-      for (i=0;  i<4; i++)
-	{
-	  NSString *comp = [ipComps objectAtIndex: i];
-	  ipComp[i] = (unsigned char)[comp intValue];
+      if ([ipComps count] == 4)
+	{ /*IPv4*/
+	  for (i=0;  i<4; i++)
+	    {
+	      NSString *comp = [ipComps objectAtIndex: i];
+	      ipComp.c[i] = (unsigned char)[comp intValue];
+	    }
+	}
+      else
+	{ /*IPv6:
+	    This is not globaly unique since we do not utilize
+	    all available data, yet the same goes for RFC1918
+	    IPv4 addresses so this should suffice in practice. */
+	  /*According to C99 Annex J.1
+	    The value of a union member other than the last one stored into
+	    is unspecified behavior.  But -base uses this to produce hash
+	    values for NSNumber also and we are pretty much doing the same
+	    here. (also see time union).
+	   */
+	  ipComp.i = [ipString hash];
 	}
     }
 
@@ -158,14 +176,14 @@ static unsigned short sequence = (unsigned short)-1;
   buffer[6] = bPtr[2];
   buffer[7] = bPtr[3];
 
-  buffer[8]  = ipComp[0];
-  buffer[9]  = ipComp[1];
-  buffer[10] = ipComp[2];
-  buffer[11] = ipComp[3];
+  buffer[8]  = ipComp.c[0];
+  buffer[9]  = ipComp.c[1];
+  buffer[10] = ipComp.c[2];
+  buffer[11] = ipComp.c[3];
 
   if (sequence == 0)
     {
-      sequence = (unsigned short)-1;
+      sequence = USHRT_MAX;
     }
   
   EOFLOGObjectFnStop();
