@@ -24,7 +24,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -40,21 +40,21 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOKeyValueCoding.m 24314 2007-01-04 22:51:31Z ayers $")
+RCS_ID("$Id: EOKeyValueCoding.m 26422 2008-04-01 17:07:27Z ayers $")
 
 #ifdef GNUSTEP
-#include <Foundation/NSObject.h>
 #include <Foundation/NSArray.h>
+#include <Foundation/NSDebug.h>
+#include <Foundation/NSDecimalNumber.h>
 #include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
+#include <Foundation/NSHashTable.h>
+#include <Foundation/NSMapTable.h>
+#include <Foundation/NSObjCRuntime.h>
+#include <Foundation/NSObject.h>
 #include <Foundation/NSString.h>
 #include <Foundation/NSValue.h>
-#include <Foundation/NSHashTable.h>
-#include <Foundation/NSException.h>
-#include <Foundation/NSObjCRuntime.h>
-#include <Foundation/NSMapTable.h>
-#include <Foundation/NSUtilities.h>
-#include <Foundation/NSDecimalNumber.h>
-#include <Foundation/NSDebug.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -251,11 +251,11 @@ initialize(void)
  * EOKeyValueCoding protocol<br/>
  * This overrides NSObjects implementation of this method.
  * Generally this method returns an array of objects
- * returned by invoking [NSObject-valueForKey:]
+ * returned by invoking valueForKey:
  * for each item in the receiver, substituting EONull for nil.
- * Keys formated like "@function.someKey" are resolved by invoking
- * <code>NSArray compute<em>Function</em>WithKey:</code> "someKey" on the receiver.
- * If the key is omitted, the function will be called with nil.
+ * Keys formated like "@function.someKeyPath" are resolved by invoking
+ * <code>NSArray compute<em>Function</em>WithKey:</code> "someKeyPath" on the receiver.
+ * If the keyPath is omitted, the function will be called with nil.
  * The following functions are supported by default:
  * <list>
  *  <item>@sum   -> -computeSumForKey:</item>
@@ -264,12 +264,9 @@ initialize(void)
  *  <item>@min   -> -computeMinForKey:</item>
  *  <item>@count -> -computeCountForKey:</item>
  * </list>
- * Computational components generally expect a key to be passed to
+ * Computational components generally expect a keyPath to be passed to
  * the function.  This is not mandatory in which case 'nil' will be supplied.
- * (i.e. you may use "@myFuncWhichCanHandleNil" as a key.)
- * As a special case the key "count" does not actually invoke
- * computeCountForKey: on receiver but returns the number of objects of 
- * the receiver.<br/>
+ * (i.e. you may use "@myFuncWhichCanHandleNil" as a key.)<br/>
  * There is no special handling of EONull.  Therefore expect exceptions
  * on EONull not responding to decimalValue and compare: when the are
  * used with this mechanism. 
@@ -280,8 +277,7 @@ initialize(void)
 
   INITIALIZE;
 
-  EOFLOGObjectFnStartCond(@"EOKVC");
-  if ([key isEqualToString: @"count"] || [key isEqualToString: @"@count"])
+  if ([key isEqual: @"count"] || [key isEqual: @"@count"])
     {
       result = [NSDecimalNumber numberWithUnsignedInt: [self count]];
     }
@@ -324,32 +320,19 @@ initialize(void)
 		     defaultResult: GDL2_EONull];
     }
 
-  EOFLOGObjectFnStopCond(@"EOKVC");
   return result;
 }
 
 /**
  * EOKeyValueCoding protocol<br/>
- * Returns the object returned by invoking [NSObject-valueForKeyPath:]
- * on the object returned by invoking [NSObject-valueForKey:]
+ * Returns the object returned by invoking valueForKeyPath:
+ * on the object returned by invoking valueForKey:
  * on the receiver with the first key component supplied by the key path,
  * with rest of the key path.<br/>
  * If the first component starts with "@", the first component includes the key
- * of the computational key component and as the form "@function.key".
+ * of the computational key component and as the form "@function.keyPath".
  * If there is only one key component, this method invokes 
- * [NSObject-valueForKey:] in the receiver with that component.
- * Unlike the reference implementation GDL2 allows you to continue the keyPath
- * in a meaningful way after @count but the path must then contain a key as
- * the computational key structure implies.
- * (i.e. you may use "@count.self.decimalValue") The actual key "self" is
- * in fact ignored during the computation, but the formal structure must be
- * maintained.<br/>
- * It should be mentioned that the reference implementation
- * would return the result of "@count" independent
- * of any additional key paths, even if they were meaningless like
- * "@count.bla.strange".  GDL2 will raise, if the object returned by
- * valueForKey:@"count.bla" (which generally is an NSDecimalNumber) raises on
- * valueForKey:@"strange".
+ * valueForKey: in the receiver with that component.
  */
 - (id)valueForKeyPath: (NSString *)keyPath
 {
@@ -357,24 +340,8 @@ initialize(void)
   id        result;
 
   EOFLOGObjectFnStartCond(@"EOKVC");
-  r = [keyPath rangeOfString: @"."];
-  if ([keyPath hasPrefix: @"@"] == YES
-      && [keyPath isEqualToString: @"@count"] == NO
-      && r.location != NSNotFound)
-    {
-      NSRange rr;
-      unsigned length;
 
-      length = [keyPath length];
-
-      rr.location = NSMaxRange(r);
-      rr.length   = length - rr.location;
-      r = [keyPath rangeOfString: @"." 
-		   options: 0
-		   range: rr];
-    }
-    
-  if (r.length == 0)
+  if ([keyPath hasPrefix: @"@"] || (r = [keyPath rangeOfString: @"."]).location == NSNotFound)
     {
       result = [self valueForKey: keyPath];
     }
@@ -387,6 +354,7 @@ initialize(void)
     }
 
   EOFLOGObjectFnStopCond(@"EOKVC");
+
   return result;
 }
 
@@ -417,7 +385,7 @@ initialize(void)
       for (i=0; i<count; i++)
         {
           left = result;
-          right = [[GDL2_ObjectAtIndexWithImp(self,oaiIMP,i) valueForKey: key] decimalValue];
+          right = [[GDL2_ObjectAtIndexWithImp(self,oaiIMP,i) valueForKeyPath: key] decimalValue];
           NSDecimalAdd(&result, &left, &right, mode);
         }
     };
@@ -455,7 +423,7 @@ initialize(void)
       for (i=0; i<count; i++)
         {
           left = result;
-          right = [[GDL2_ObjectAtIndexWithImp(self,oaiIMP,i) valueForKey: key] decimalValue];
+          right = [[GDL2_ObjectAtIndexWithImp(self,oaiIMP,i) valueForKeyPath: key] decimalValue];
           NSDecimalAdd(&result, &left, &right, mode);
         }
     }
@@ -476,10 +444,12 @@ initialize(void)
 
 - (id)computeCountForKey: (NSString *)key
 {
+  NSArray *array;
   id result;
 
   EOFLOGObjectFnStartCond(@"EOKVC");
-  result = [NSDecimalNumber numberWithUnsignedInt: [self count]];
+  array = key ? [self valueForKeyPath: key] : self;
+  result = [NSDecimalNumber numberWithUnsignedInt: [array count]];
 
   EOFLOGObjectFnStopCond(@"EOKVC");
   return result;
@@ -506,12 +476,12 @@ initialize(void)
       for(i=0; i<count && (resultVal == nil || resultVal == GDL2_EONull); i++)
 	{
 	  result    = GDL2_ObjectAtIndexWithImp(self,oaiIMP,i);
-	  resultVal = [result valueForKey: key];
+	  resultVal = [result valueForKeyPath: key];
 	}          
       for (; i<count; i++)
 	{
 	  current    = GDL2_ObjectAtIndexWithImp(self,oaiIMP,i);
-	  currentVal = [current valueForKey: key];
+	  currentVal = [current valueForKeyPath: key];
 
 	  if (currentVal == nil || currentVal == GDL2_EONull)
             continue;
@@ -549,12 +519,12 @@ initialize(void)
       for(i=0; i<count && (resultVal == nil || resultVal == GDL2_EONull); i++)
 	{
 	  result    = GDL2_ObjectAtIndexWithImp(self,oaiIMP,i);
-	  resultVal = [result valueForKey: key];
+	  resultVal = [result valueForKeyPath: key];
 	}          
       for (; i<count; i++)
 	{
 	  current    = GDL2_ObjectAtIndexWithImp(self,oaiIMP,i);
-	  currentVal = [current valueForKey: key];
+	  currentVal = [current valueForKeyPath: key];
 
 	  if (currentVal == nil || currentVal == GDL2_EONull) continue;
 
