@@ -5,8 +5,8 @@
 
    Date: Jan 2005
 
-   $Revision: 23874 $
-   $Date: 2006-10-15 14:23:42 +0200 (Son, 15 Okt 2006) $
+   $Revision: 27923 $
+   $Date: 2009-02-19 17:29:11 +0100 (Don, 19. Feb 2009) $
 
    <abstract></abstract>
 
@@ -16,7 +16,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,7 +32,7 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOPrivate.m 23874 2006-10-15 12:23:42Z ratmice $")
+RCS_ID("$Id: EOPrivate.m 27923 2009-02-19 16:29:11Z ayers $")
 
 #include <Foundation/Foundation.h>
 #define GSI_ARRAY_TYPES GSUNION_OBJ
@@ -48,6 +48,7 @@ RCS_ID("$Id: EOPrivate.m 23874 2006-10-15 12:23:42Z ratmice $")
 #include <EOControl/EOEditingContext.h>
 #include <EOControl/EOFault.h>
 #include <EOControl/EOMutableKnownKeyDictionary.h>
+#include <EOControl/EONull.h>
 
 #include "EOPrivate.h"
 
@@ -115,6 +116,8 @@ void GDL2_PrivateInit()
   static BOOL initialized=NO;
   if (!initialized)
     {
+      initialized = YES;
+
       // ==== Classes ====
       GDL2_NSArrayClass=[NSArray class];
       GDL2_NSMutableArrayClass=[NSMutableArray class];
@@ -176,7 +179,7 @@ void GDL2_PrivateInit()
       GDL2_MKKD_indexForKeyIMP=(GDL2IMP_UINT)[GDL2_MKKDClass instanceMethodForSelector:@selector(indexForKey:)];
       GDL2_EOMKKDInitializer_indexForKeyIMP=(GDL2IMP_UINT)[GDL2_EOMKKDInitializerClass instanceMethodForSelector:@selector(indexForKey:)];
 
-      GDL2_EOEditingContext_recordObjectGlobalIDIMP==[GDL2_EOEditingContextClass instanceMethodForSelector:@selector(recordObject:globalID:)];
+      GDL2_EOEditingContext_recordObjectGlobalIDIMP=[GDL2_EOEditingContextClass instanceMethodForSelector:@selector(recordObject:globalID:)];
       GDL2_EOEditingContext_objectForGlobalIDIMP=[GDL2_EOEditingContextClass instanceMethodForSelector:@selector(objectForGlobalID:)];
       GDL2_EOEditingContext_globalIDForObjectIMP=[GDL2_EOEditingContextClass instanceMethodForSelector:@selector(globalIDForObject:)];
 
@@ -484,6 +487,16 @@ static SEL eqSel;
   return self;
 }
 
+- (id) copyWithZone:(NSZone *)zone
+{
+  return [self mutableCopyWithZone:zone];
+}
+
+- (id) mutableCopyWithZone:(NSZone *)zone
+{
+  return [[GDL2NonRetainingMutableArray allocWithZone:zone] initWithArray:self copyItems:NO];
+}
+
 /* designated initializer */
 - (id) initWithCapacity:(unsigned)capacity
 {
@@ -629,3 +642,27 @@ static SEL eqSel;
 }
 
 @end
+
+
+BOOL
+GDL2_isLegalDBName(NSString* name)
+{
+  static NSCharacterSet *illegalSet = nil;
+  NSRange range;
+  
+  if (illegalSet == nil)
+    {
+      NSMutableCharacterSet *mutableSet;
+      illegalSet = [NSCharacterSet alphanumericCharacterSet];
+      mutableSet = AUTORELEASE([illegalSet mutableCopy]);
+      [mutableSet addCharactersInString:@"_-"];
+      illegalSet = RETAIN([mutableSet invertedSet]);
+    }
+
+  if (![name length])
+    { 
+      return NO;
+    }
+  range = [name rangeOfCharacterFromSet: illegalSet];
+  return (range.location == NSNotFound) ? YES : NO;
+}
