@@ -6,8 +6,8 @@
    Author: Mirko Viviani <mirko.viviani@gmail.com>
    Date: February 2000
 
-   $Revision: 23510 $
-   $Date: 2006-09-14 18:06:21 +0200 (Don, 14 Sep 2006) $
+   $Revision: 27923 $
+   $Date: 2009-02-19 17:29:11 +0100 (Don, 19. Feb 2009) $
 
    <abstract></abstract>
 
@@ -17,7 +17,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,20 +33,21 @@
 
 #include "config.h"
 
-RCS_ID("$Id: EOQualifier.m 23510 2006-09-14 16:06:21Z ayers $")
+RCS_ID("$Id: EOQualifier.m 27923 2009-02-19 16:29:11Z ayers $")
 
 #include <stdio.h>
 #include <string.h>
+#include <stdarg.h>
 
 #ifdef GNUSTEP
-#include <Foundation/NSDictionary.h>
-#include <Foundation/NSSet.h>
-#include <Foundation/NSScanner.h>
-#include <Foundation/NSUtilities.h>
-#include <Foundation/NSException.h>
-#include <Foundation/NSValue.h>
 #include <Foundation/NSCoder.h>
 #include <Foundation/NSDebug.h>
+#include <Foundation/NSDictionary.h>
+#include <Foundation/NSEnumerator.h>
+#include <Foundation/NSException.h>
+#include <Foundation/NSScanner.h>
+#include <Foundation/NSSet.h>
+#include <Foundation/NSValue.h>
 #else
 #include <Foundation/Foundation.h>
 #endif
@@ -150,28 +151,6 @@ static BOOL (*digitCIM)(id,SEL,unichar);
   return qualifier;
 }
 
-+ (EOQualifier *)qualifierWithQualifierFormat: (NSString *)format
-				    arguments: (NSArray *)args
-{
-  [self notImplemented: _cmd];
-  return nil;
-}
-
-- (void)dealloc
-{
-#ifdef DEBUG
-//  NSDebugFLog(@"Dealloc EOQualifier %p. ThreadID=%p",
-//              (void*)self,(void*)objc_thread_id());
-#endif
-
-  [super dealloc];
-
-#ifdef DEBUG
-//  NSDebugFLog(@"Stop Dealloc EOQualifier %p. ThreadID=%p",
-//              (void*)self,(void*)objc_thread_id());
-#endif
-}
-
 static NSString *getOperator(const unichar **cFormat, const unichar **s)
 {
   NSString *operator;
@@ -216,6 +195,7 @@ static id
 getKey(const unichar **cFormat, 
        const unichar **s,
        BOOL *isKeyValue,
+       NSEnumerator *argsEnum,
        va_list *args)
 {
   NSMutableString *key;
@@ -223,6 +203,8 @@ getKey(const unichar **cFormat,
   unichar quoteChar;
   BOOL quoted = NO;
   BOOL literalNumber = NO;
+  BOOL isQualVar = NO;
+  BOOL isFormat = NO;
 
   while (**s && spaceCIM(spaceSet, cimSEL, **s))
     (*s)++;
@@ -290,6 +272,7 @@ getKey(const unichar **cFormat,
 		     || **s == '@' || **s == '#' || **s == '_' || **s == '$' 
 		     || **s == '%' || **s == '.' || **s == '-'))
         {
+	  /* Parse format specifier */
 	  if (**s == '%')
 	    {
 	      const char *argString;
@@ -303,6 +286,11 @@ getKey(const unichar **cFormat,
 
 	      int argInt;
 
+	      /* TODO userInfo would be nice */
+	      if (isQualVar)
+		[NSException raise:NSInvalidArgumentException
+				format:@"error parsing qualifier format"];
+
 	      if (isKeyValue)
 	        {
 		  *isKeyValue = YES;
@@ -311,7 +299,14 @@ getKey(const unichar **cFormat,
 	      switch (*(*s+1))
 		{
 		case '@':
-		  argObj = va_arg(*args, id);
+		  if (args)
+		    {
+		      argObj = va_arg(*args, id);
+		    }
+		  else
+		    {
+		      argObj = [argsEnum nextObject];
+		    }
 
 		  if (isKeyValue && *isKeyValue == YES 
 		      && quoted == NO && classString == nil)
@@ -336,7 +331,14 @@ getKey(const unichar **cFormat,
 		  break;
 
 		case 's':
-		  argString = va_arg(*args, const char *);
+		  if (args)
+		    {
+		      argString = va_arg(*args, const char *);
+		    }
+		  else
+		    {
+		      argString = [[argsEnum nextObject] cString];
+		    }
 
 		  if (isKeyValue && *isKeyValue == YES
 		      && quoted == NO && classString == nil)
@@ -363,7 +365,14 @@ getKey(const unichar **cFormat,
 		  break;
 
 		case 'd':
-		  argInt = va_arg(*args, int);
+		  if (args)
+		    {
+		      argInt = va_arg(*args, int);
+		    }
+		  else
+		    {
+		      argInt = [[argsEnum nextObject] intValue];
+		    }
 
 		  if (isKeyValue && *isKeyValue == YES
 		      && quoted == NO && classString == nil)
@@ -390,9 +399,16 @@ getKey(const unichar **cFormat,
 		  break;
 
 		case 'f':
-		  /* 'float' is promoted to 'double' when passed through '...'
-		     (so you should pass `double' not `float' to `va_arg') */
-		  argFloat = va_arg(*args, double);
+		  if (args)
+		    {
+		      /* 'float' is promoted to 'double' when passed through '...'
+			 (so you should pass `double' not `float' to `va_arg') */
+		      argFloat = va_arg(*args, double);
+		    }
+		  else
+		    {
+		      argFloat = [[argsEnum nextObject] doubleValue];
+		    }
 
 		  if (isKeyValue && *isKeyValue == YES && quoted == NO
 		      && classString == nil)
@@ -420,10 +436,20 @@ getKey(const unichar **cFormat,
 		  break;
 
 		case '%':
-		  *cFormat = *s + 2;
-		  (*s)++;
-		  [key appendString: [NSString stringWithCharacters: *cFormat
-					       length: *s - *cFormat]];
+		  {
+		    /* The documentation states that '%%' results in a literal '%'.
+		       The intention seems to be to allow key/key qualifiers like foo = %%foo
+		       to be interpreted as foo = %foo. (Useful for in memory evaluation?) 
+		       Yet WO45 actually fails to parse this, but we can do better.  */
+		    NSString *str;
+
+		    (*s)++;
+		    str = [NSString stringWithCharacters: *cFormat
+				    length: *s - *cFormat];
+		    [key appendString: str];
+					       
+		    *cFormat = *s + 1;
+		  }
 		  break;
 
 		default:
@@ -432,26 +458,66 @@ getKey(const unichar **cFormat,
 		      = @"%@ -- %@: unrecognized character (%@) in the conversion specification";
 		    NSString *specChar 
 		      = [NSString stringWithCharacters: (*s + 1) length: 1];
-		    [NSException raise: NSInvalidArgumentException
+		    [NSException raise: NSInvalidArgumentException 
 				 format: fmt, @"EOQualifier", 
 				 @"qualifierParser", specChar];
 		    break;
 		  } 
 		}
 	    }
+	  else if (**s == '$')
+	    {
+ 	      /* TODO userInfo would be nice */
+	      if (isFormat)
+		[NSException raise:NSInvalidArgumentException
+				format:@"error parsing qualifier format"];
+	      if (isKeyValue)
+		{
+		  *isKeyValue = YES;
+		  isQualVar = YES;
+		}
+	    }
 
 	  (*s)++;
         }
 
       if (*cFormat != *s)
 	{
-	  NSString *str = [NSString stringWithCharacters: *cFormat
-				    length: *s - *cFormat];
+	  unsigned int length = *s - *cFormat;
+	  const unichar *c = *cFormat;
+	  NSString *str;
+
+	  if (isKeyValue && c[0] == '$')
+	    {
+	      c++;
+	      length--;	      
+	    }
+
+	  str  = [NSString stringWithCharacters: c 
+				    length: length];
 	  [key appendString: str];
 	}
     }
 
-  if (isKeyValue)
+  if (classString && (!(quoted || literalNumber)))
+    {
+      [NSException raise:NSInvalidArgumentException
+		   format:@"expected string literal after cast to class"];
+    }
+
+  /* not sure about this !isQualVar */
+  if (isQualVar)
+    {
+      if (!GDL2_isLegalDBName(key))
+	{
+	  NSString *format 
+	    = [NSString stringWithFormat: @"illegal qualifier variable $%@",key];
+	  [NSException raise:NSInvalidArgumentException
+		       format:format];
+	}
+      key = (id)[[EOQualifierVariable alloc] initWithKey:key];
+    }
+  else if (isKeyValue)
     {
       *isKeyValue = (quoted || literalNumber);
 
@@ -467,7 +533,8 @@ getKey(const unichar **cFormat,
   return key;
 }
 
-static BOOL isNotQualifier(const unichar **cFormat, const unichar **s)
+static BOOL
+isNotQualifier(const unichar **cFormat, const unichar **s)
 {
   while (**s && spaceCIM(spaceSet,cimSEL,**s))
     (*s)++;
@@ -491,7 +558,8 @@ static BOOL isNotQualifier(const unichar **cFormat, const unichar **s)
   return NO;
 }
 
-static Class whichQualifier(const unichar **cFormat, const unichar **s)
+static Class
+whichQualifier(const unichar **cFormat, const unichar **s)
 {
   while (**s && spaceCIM(spaceSet,cimSEL,**s))
     (*s)++;
@@ -527,9 +595,10 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
   return Nil;
 }
 
-+ (EOQualifier *)qualifierWithQualifierFormat: (NSString *)format
-				   varargList: (va_list)args
+static EOQualifier *
+_qualifierWithArgs(id self, SEL _cmd, NSString *format, NSArray *array, va_list *args)
 {
+  NSEnumerator *argEnum = [array objectEnumerator];
   unichar *s0;
   const unichar *s;
   const unichar *cFormat;
@@ -594,9 +663,9 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
       }
       
       notQual = isNotQualifier(&cFormat, &s);
-      leftKey = getKey(&cFormat, &s, NULL, &args);
+      leftKey = getKey(&cFormat, &s, NULL, argEnum, args);
       operator = getOperator(&cFormat, &s);
-      rightKey = getKey(&cFormat, &s, &isKeyValue, &args);
+      rightKey = getKey(&cFormat, &s, &isKeyValue, argEnum, args);
 
       operatorSelector = [EOQualifier operatorSelectorForString: operator];
       if (!operatorSelector)
@@ -745,6 +814,24 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
   return qualifier;
 }
 
++ (EOQualifier *)qualifierWithQualifierFormat: (NSString *)format
+				    arguments: (NSArray *)args
+{
+  return _qualifierWithArgs(self, _cmd, format, args, NULL);
+}
+
++ (EOQualifier *)qualifierWithQualifierFormat: (NSString *)format
+				   varargList: (va_list)args
+{
+  EOQualifier *qualifier;
+  va_list varargs;
+
+  va_copy(varargs, args);
+  qualifier = _qualifierWithArgs(self, _cmd, format, nil, &varargs);
+  va_end(varargs);
+  return qualifier;
+}
+
 + (EOQualifier *)qualifierToMatchAllValues: (NSDictionary *)values
 {
   NSEnumerator *keyEnumerator;
@@ -851,7 +938,7 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
   if (sel_eq(selector, EOQualifierOperatorEqual))
     return @"=";
   else if (sel_eq(selector, EOQualifierOperatorNotEqual))
-    return @"!=";
+    return @"<>";
   else if (sel_eq(selector, EOQualifierOperatorLessThan))
     return @"<";
   else if (sel_eq(selector, EOQualifierOperatorGreaterThan))
@@ -888,6 +975,8 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
     return EOQualifierOperatorNotEqual;
   else if ([string isEqualToString: @"!="])
     return EOQualifierOperatorNotEqual;
+  else if ([string isEqualToString: @"contains"])
+    return EOQualifierOperatorContains;
   else if ([string isEqualToString: @"doesContain"])
     return EOQualifierOperatorContains;
   else if ([string isEqualToString: @"like"])
@@ -936,7 +1025,7 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
 {
   NSMutableDictionary* bindings = (id)[NSMutableDictionary dictionary];
   [self _addBindingsToDictionary:bindings];
-  return [bindings allKeys];
+  return [bindings allValues];
 }
 
 //NO
@@ -1068,6 +1157,11 @@ static Class whichQualifier(const unichar **cFormat, const unichar **s)
   [archiver encodeObject: _key forKey: @"_key"];
 }
 
+- (NSString *) description
+{
+  return _key;
+}
+
 @end
 
 /*
@@ -1191,13 +1285,23 @@ _isLike (NSString *self, NSString *regExpr, BOOL isCaseSensative)
 
 	      for (; *cScanned != 0; cScanned++)
 		{
-		  if (*cScanned == '?' 
-		      && tokens[c - 1] != isLikeWildCardTokenS)
+		  if (*cScanned == '?') 
 		    {
-		      tokens[c++] = isLikeWildCardTokenQ; 
+		      /* sanitize the token list (*??bar -> ?*?bar -> ??*bar)
+			 throughout this loop */
+		      if (c != 0 && tokens[c - 1] == isLikeWildCardTokenS)
+			{
+			  /* replace *? with ?* which both match 1 or more */
+			  tokens[c - 1] = isLikeWildCardTokenQ;
+			  tokens[c++] = isLikeWildCardTokenS;
+			}
+		      else
+			{
+		          tokens[c++] = isLikeWildCardTokenQ;
+			}
 		    }
-		  else if (*cScanned == '*'
-		      && tokens[c - 1] != isLikeWildCardTokenS)
+		  else if (*cScanned == '*' /* ignore ** */
+		      && (c == 0 || tokens[c - 1] != isLikeWildCardTokenS))
 		    {
 		      tokens[c++] = isLikeWildCardTokenS;
 		    }
@@ -1218,10 +1322,13 @@ _isLike (NSString *self, NSString *regExpr, BOOL isCaseSensative)
 	}
       else if (tokens[i] == isLikeWildCardTokenS)
 	{
+	  // no more tokens except a * we have a match.
 	  if (i == c - 1)
 	    {
 	      return YES;
 	    }
+
+	  // tokens[i + 1] should be the 'bar' in *bar  
 	  [valueScanner scanUpToString: tokens[i + 1]
 			intoString: 0];
 	}
