@@ -9,7 +9,7 @@
 
    The GNUstep Database Library is free software; you can redistribute it 
    and/or modify it under the terms of the GNU Lesser General Public License 
-   as published by the Free Software Foundation; either version 2, 
+   as published by the Free Software Foundation; either version 3, 
    or (at your option) any later version.
 
    The GNUstep Database Library is distributed in the hope that it will be 
@@ -35,6 +35,7 @@
 #include <Foundation/Foundation.h>
 #endif
 
+#include <GNUstepBase/GNUstep.h>
 #include <GNUstepBase/GSObjCRuntime.h>
 
 #include "EODisplayGroup.h"
@@ -56,7 +57,7 @@ static NSMapTable *_objectToAssociations;
   
   if (associations)
     {
-      [associations makeObjectsPerform: @selector(breakConnection)];
+      [associations makeObjectsPerformSelector: @selector(breakConnection)];
       NSMapRemove(_objectToAssociations, object);
     }
 }
