@@ -9,7 +9,7 @@
 
    The GNUstep Database Library is free software; you can redistribute it 
    and/or modify it under the terms of the GNU Lesser General Public License 
-   as published by the Free Software Foundation; either version 2, 
+   as published by the Free Software Foundation; either version 3, 
    or (at your option) any later version.
 
    The GNUstep Database Library is distributed in the hope that it will be 
@@ -33,6 +33,7 @@
 #include <AppKit/AppKit.h>
 #endif
 
+#include <GNUstepBase/GNUstep.h>
 #include "EOControlAssociation.h"
 #include "EODisplayGroup.h"
 #include "EOPopUpAssociation.h"
@@ -199,7 +200,7 @@
         {
 	  int tag = [[self valueForAspect:@"selectedTag"] intValue];
 
-	  [_object selectItemAtIndex:tag];
+	  [_object selectItemAtIndex:[_object indexOfItemWithTag:tag]];
 	}
     }
   else if (subclassFlags & SelectedTitleAspectMask)
