@@ -9,7 +9,7 @@
 
    The GNUstep Database Library is free software; you can redistribute it 
    and/or modify it under the terms of the GNU Lesser General Public License 
-   as published by the Free Software Foundation; either version 2, 
+   as published by the Free Software Foundation; either version 3, 
    or (at your option) any later version.
 
    The GNUstep Database Library is distributed in the hope that it will be 
@@ -34,6 +34,7 @@
 #include <AppKit/AppKit.h>
 #endif
 
+#include <GNUstepBase/GNUstep.h>
 #include "EOControlAssociation.h"
 #include "EORadioMatrixAssociation.h"
 #include "SubclassFlags.h"
@@ -54,7 +55,7 @@
    
       while (j-- > 0)
         {
-          if ([[_cells[i][j] title] isEqual: title])
+	  if ([[[self cellAtRow: i column: j] title] isEqual: title])
             {
               [self selectCellAtRow:i column:j];
               return YES;
