@@ -9,7 +9,7 @@
 
    The GNUstep Database Library is free software; you can redistribute it 
    and/or modify it under the terms of the GNU Lesser General Public License 
-   as published by the Free Software Foundation; either version 2, 
+   as published by the Free Software Foundation; either version 3, 
    or (at your option) any later version.
 
    The GNUstep Database Library is distributed in the hope that it will be 
@@ -25,6 +25,7 @@
 
 #ifdef GNUSTEP
 #include <Foundation/NSArray.h>
+#include <Foundation/NSEnumerator.h>
 #include <Foundation/NSMapTable.h>
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSString.h>
@@ -38,7 +39,12 @@
 #include <AppKit/AppKit.h>
 #endif
 
+#include <GNUstepBase/GNUstep.h>
 #include "EOColumnAssociation.h"
+#include "EOControlAssociation.h"
+#include "EOPickTextAssociation.h"
+#include "EOActionAssociation.h"
+#include "EOActionInsertionAssociation.h"
 #include "EODisplayGroup.h"
 @implementation EOTableViewAssociation
 
