@@ -11,7 +11,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
-   version 2.1 of the License, or (at your option) any later version.
+   version 3 of the License, or (at your option) any later version.
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,11 +26,24 @@
 #ifndef __EOModeler_EODefines_h__
 #define __EOModeler_EODefines_h__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #ifdef GNUSTEP_WITH_DLL
 
 #if BUILD_libEOModeler_DLL
+
+# if defined(__MINGW32__)
+  /* On Mingw, the compiler will export all symbols automatically, so
+   * __declspec(dllexport) is not needed.
+   */
+#  define GDL2MODELER_EXPORT extern
+#  define GDL2MODELER_DECLARE
+# else
 #  define GDL2MODELER_EXPORT  __declspec(dllexport)
 #  define GDL2MODELER_DECLARE __declspec(dllexport)
+# endif
 #else
 #  define GDL2MODELER_EXPORT  extern __declspec(dllimport)
 #  define GDL2MODELER_DECLARE __declspec(dllimport)
@@ -43,4 +56,8 @@
 
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* __EOMODELER_EODefines_h__ */
