@@ -12,7 +12,7 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  version 3 of the License, or (at your option) any later version.
  
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -26,11 +26,21 @@
 **/
 
 #include <AppKit/AppKit.h>
+
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
+#include <Foundation/NSArray.h>
+#endif
+
 #include "EOModeler/EOMInspector.h"
 #include "EOModeler/EOMInspectorController.h"
 #include "EOModeler/EOModelerApp.h"
 #include "EOModeler/EOModelerEditor.h"
-#include <Foundation/NSArray.h>
+
+#include <GNUstepBase/GNUstep.h>
+#include <GNUstepBase/GSObjCRuntime.h>
+
 static NSMapTable *_inspectorsByClass;
 
 
