@@ -12,7 +12,7 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  version 3 of the License, or (at your option) any later version.
  
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,15 +30,24 @@
 #include <EOModeler/EOMInspectorController.h>
 #include <EOModeler/EOModelerEditor.h>
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSBox.h>
 #include <AppKit/NSButtonCell.h>
 #include <AppKit/NSMatrix.h>
 #include <AppKit/NSScrollView.h>
 #include <AppKit/NSPanel.h>
+#include <AppKit/NSView.h>
+#endif
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSNotification.h>
 #include <Foundation/NSException.h>
 #include <Foundation/NSArray.h>
+#endif
 
 static EOMInspectorController *_sharedInspectorController;
 
@@ -166,7 +175,7 @@ static NSMatrix *_iconBar;
 	      [inspector prepareForDisplay];
 	  
 	      if ([lastInspector view] && lastInspector != inspector)
-	        [[window contentView] removeSubview:[lastInspector view]];
+                [[lastInspector view] removeFromSuperview];
 
 	      if ([inspector view] && lastInspector != inspector)
 	        [[window contentView] addSubview:[inspector view]];
@@ -200,7 +209,7 @@ static NSMatrix *_iconBar;
   [inspector prepareForDisplay];
   
   if ([lastInspector view] && lastInspector != inspector)
-    [[window contentView] removeSubview:[lastInspector view]];
+    [[lastInspector view] removeFromSuperview];
 
   if ([inspector view] && lastInspector != inspector)
     [[window contentView] addSubview:[inspector view]];
