@@ -12,7 +12,7 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  version 3 of the License, or (at your option) any later version.
  
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,13 +25,21 @@
   </license>
 **/
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
+#include <Foundation/NSArray.h>
+#include <Foundation/NSDictionary.h>
+#endif
+
+#include <EOAccess/EOModel.h>
+#include <EOAccess/EOModelGroup.h>
+
 #include "EOModeler/EODefines.h"
 #include "EOModeler/EOModelerApp.h"
 #include "EOModeler/EOModelerDocument.h"
 
-#include <EOAccess/EOModel.h>
-#include <EOAccess/EOModelGroup.h>
-#include <Foundation/NSArray.h>
+#include <GNUstepBase/GNUstep.h>
 
 EOModelerApp *EOMApp;
 NSString *EOMSelectionChangedNotification = @"EOModelerSelectionChanged";
