@@ -12,7 +12,7 @@
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
+  version 3 of the License, or (at your option) any later version.
  
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,8 +30,12 @@
 #include "EOModeler/EOModelerEditor.h"
 #include "EOModeler/EOModelerApp.h"
 
+#ifdef NeXT_GUI_LIBRARY
+#include <AppKit/AppKit.h>
+#else
 #include <AppKit/NSMenuItem.h>
 #include <AppKit/NSOpenPanel.h>
+#endif
 
 #include <EOInterface/EODisplayGroup.h>
 
@@ -44,6 +48,9 @@
 
 #include <EOControl/EOEditingContext.h>
 
+#ifdef NeXT_Foundation_LIBRARY
+#include <Foundation/Foundation.h>
+#else
 #include <Foundation/NSAttributedString.h>
 #include <Foundation/NSCharacterSet.h>
 #include <Foundation/NSException.h>
@@ -51,6 +58,9 @@
 #include <Foundation/NSUndoManager.h>
 #include <Foundation/NSUserDefaults.h>
 #include <Foundation/NSValue.h>
+#endif
+
+#include <GNUstepBase/GNUstep.h>
 
 @interface ConsistencyResults : NSObject 
 + (id) sharedConsistencyPanel;
@@ -61,6 +71,19 @@ showOnSuccess:(BOOL)flag;
 static Class      _defaultEditorClass;
 static EOModelerEditor *_currentEditorForDocument;
 
+/* FIXME we cross the library->application boundry whenever working
+ * with the ConsistencyResults class which is declared in DBModeler
+ * theres a few ways this is crossed:
+ *
+ * enabling/disabling the cancel button
+ * appending text
+ * avoiding running the panel if all checks pass.
+ *
+ * this could possibly be done with private methods in this class
+ * called from the receiver of an EOMCheckConsistencyEndNotification 
+ * on the notification -object (or something).
+ */
+
 /** Notification sent when beginning consistency checks.
   * The notifications object is the EOModelerDocument.
   * The receiver should call -appendConsistencyCheckErrorText:
@@ -180,6 +203,8 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
   NS_HANDLER
     return nil;
   NS_ENDHANDLER
+
+  return nil;
 }
 
 - (EOModel *)model;
@@ -244,6 +269,8 @@ NSString *EOMConsistencyModelObjectKey = @"EOMConsistencyModelObjectKey";
 		       [localException reason]);
     return NO;
   NS_ENDHANDLER
+
+  return NO;
 }
 
 - (BOOL)checkCloseDocument
